# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .get_account import *
from .get_caller_identity import *
from .get_file_crc64_checksum import *
from .get_msc_sub_contact_verification_message import *
from .get_msc_sub_contacts import *
from .get_msc_sub_subscriptions import *
from .get_msc_sub_webhooks import *
from .get_regions import *
from .get_zones import *
from .msc_sub_contract import *
from .msc_sub_subscription import *
from .msc_sub_webhook import *
from .provider import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_alicloud.ackone as __ackone
    ackone = __ackone
    import pulumi_alicloud.actiontrail as __actiontrail
    actiontrail = __actiontrail
    import pulumi_alicloud.adb as __adb
    adb = __adb
    import pulumi_alicloud.alb as __alb
    alb = __alb
    import pulumi_alicloud.aligreen as __aligreen
    aligreen = __aligreen
    import pulumi_alicloud.alikafka as __alikafka
    alikafka = __alikafka
    import pulumi_alicloud.amqp as __amqp
    amqp = __amqp
    import pulumi_alicloud.apigateway as __apigateway
    apigateway = __apigateway
    import pulumi_alicloud.arms as __arms
    arms = __arms
    import pulumi_alicloud.bastionhost as __bastionhost
    bastionhost = __bastionhost
    import pulumi_alicloud.bp as __bp
    bp = __bp
    import pulumi_alicloud.brain as __brain
    brain = __brain
    import pulumi_alicloud.bss as __bss
    bss = __bss
    import pulumi_alicloud.cas as __cas
    cas = __cas
    import pulumi_alicloud.cassandra as __cassandra
    cassandra = __cassandra
    import pulumi_alicloud.cddc as __cddc
    cddc = __cddc
    import pulumi_alicloud.cdn as __cdn
    cdn = __cdn
    import pulumi_alicloud.cen as __cen
    cen = __cen
    import pulumi_alicloud.cfg as __cfg
    cfg = __cfg
    import pulumi_alicloud.chatbot as __chatbot
    chatbot = __chatbot
    import pulumi_alicloud.clickhouse as __clickhouse
    clickhouse = __clickhouse
    import pulumi_alicloud.cloudauth as __cloudauth
    cloudauth = __cloudauth
    import pulumi_alicloud.cloudconnect as __cloudconnect
    cloudconnect = __cloudconnect
    import pulumi_alicloud.cloudfirewall as __cloudfirewall
    cloudfirewall = __cloudfirewall
    import pulumi_alicloud.cloudmonitor as __cloudmonitor
    cloudmonitor = __cloudmonitor
    import pulumi_alicloud.cloudsso as __cloudsso
    cloudsso = __cloudsso
    import pulumi_alicloud.cloudstoragegateway as __cloudstoragegateway
    cloudstoragegateway = __cloudstoragegateway
    import pulumi_alicloud.cms as __cms
    cms = __cms
    import pulumi_alicloud.compute as __compute
    compute = __compute
    import pulumi_alicloud.config as __config
    config = __config
    import pulumi_alicloud.cr as __cr
    cr = __cr
    import pulumi_alicloud.cs as __cs
    cs = __cs
    import pulumi_alicloud.das as __das
    das = __das
    import pulumi_alicloud.databasefilesystem as __databasefilesystem
    databasefilesystem = __databasefilesystem
    import pulumi_alicloud.databasegateway as __databasegateway
    databasegateway = __databasegateway
    import pulumi_alicloud.datahub as __datahub
    datahub = __datahub
    import pulumi_alicloud.dataworks as __dataworks
    dataworks = __dataworks
    import pulumi_alicloud.dbs as __dbs
    dbs = __dbs
    import pulumi_alicloud.dcdn as __dcdn
    dcdn = __dcdn
    import pulumi_alicloud.ddos as __ddos
    ddos = __ddos
    import pulumi_alicloud.dds as __dds
    dds = __dds
    import pulumi_alicloud.dfs as __dfs
    dfs = __dfs
    import pulumi_alicloud.directmail as __directmail
    directmail = __directmail
    import pulumi_alicloud.dms as __dms
    dms = __dms
    import pulumi_alicloud.dns as __dns
    dns = __dns
    import pulumi_alicloud.drds as __drds
    drds = __drds
    import pulumi_alicloud.dts as __dts
    dts = __dts
    import pulumi_alicloud.eais as __eais
    eais = __eais
    import pulumi_alicloud.ebs as __ebs
    ebs = __ebs
    import pulumi_alicloud.eci as __eci
    eci = __eci
    import pulumi_alicloud.ecp as __ecp
    ecp = __ecp
    import pulumi_alicloud.ecs as __ecs
    ecs = __ecs
    import pulumi_alicloud.edas as __edas
    edas = __edas
    import pulumi_alicloud.eds as __eds
    eds = __eds
    import pulumi_alicloud.eflo as __eflo
    eflo = __eflo
    import pulumi_alicloud.ehpc as __ehpc
    ehpc = __ehpc
    import pulumi_alicloud.eipanycast as __eipanycast
    eipanycast = __eipanycast
    import pulumi_alicloud.elasticsearch as __elasticsearch
    elasticsearch = __elasticsearch
    import pulumi_alicloud.emr as __emr
    emr = __emr
    import pulumi_alicloud.emrv2 as __emrv2
    emrv2 = __emrv2
    import pulumi_alicloud.ens as __ens
    ens = __ens
    import pulumi_alicloud.esa as __esa
    esa = __esa
    import pulumi_alicloud.ess as __ess
    ess = __ess
    import pulumi_alicloud.eventbridge as __eventbridge
    eventbridge = __eventbridge
    import pulumi_alicloud.expressconnect as __expressconnect
    expressconnect = __expressconnect
    import pulumi_alicloud.fc as __fc
    fc = __fc
    import pulumi_alicloud.fnf as __fnf
    fnf = __fnf
    import pulumi_alicloud.ga as __ga
    ga = __ga
    import pulumi_alicloud.governance as __governance
    governance = __governance
    import pulumi_alicloud.gpdb as __gpdb
    gpdb = __gpdb
    import pulumi_alicloud.graphdatabase as __graphdatabase
    graphdatabase = __graphdatabase
    import pulumi_alicloud.gwlb as __gwlb
    gwlb = __gwlb
    import pulumi_alicloud.hbase as __hbase
    hbase = __hbase
    import pulumi_alicloud.hbr as __hbr
    hbr = __hbr
    import pulumi_alicloud.hologram as __hologram
    hologram = __hologram
    import pulumi_alicloud.imm as __imm
    imm = __imm
    import pulumi_alicloud.imp as __imp
    imp = __imp
    import pulumi_alicloud.ims as __ims
    ims = __ims
    import pulumi_alicloud.iot as __iot
    iot = __iot
    import pulumi_alicloud.kms as __kms
    kms = __kms
    import pulumi_alicloud.kvstore as __kvstore
    kvstore = __kvstore
    import pulumi_alicloud.lindorm as __lindorm
    lindorm = __lindorm
    import pulumi_alicloud.log as __log
    log = __log
    import pulumi_alicloud.marketplace as __marketplace
    marketplace = __marketplace
    import pulumi_alicloud.maxcompute as __maxcompute
    maxcompute = __maxcompute
    import pulumi_alicloud.message as __message
    message = __message
    import pulumi_alicloud.mhub as __mhub
    mhub = __mhub
    import pulumi_alicloud.mns as __mns
    mns = __mns
    import pulumi_alicloud.mongodb as __mongodb
    mongodb = __mongodb
    import pulumi_alicloud.mse as __mse
    mse = __mse
    import pulumi_alicloud.nas as __nas
    nas = __nas
    import pulumi_alicloud.nlb as __nlb
    nlb = __nlb
    import pulumi_alicloud.ocean as __ocean
    ocean = __ocean
    import pulumi_alicloud.oos as __oos
    oos = __oos
    import pulumi_alicloud.opensearch as __opensearch
    opensearch = __opensearch
    import pulumi_alicloud.oss as __oss
    oss = __oss
    import pulumi_alicloud.ots as __ots
    ots = __ots
    import pulumi_alicloud.pai as __pai
    pai = __pai
    import pulumi_alicloud.polardb as __polardb
    polardb = __polardb
    import pulumi_alicloud.privatelink as __privatelink
    privatelink = __privatelink
    import pulumi_alicloud.pvtz as __pvtz
    pvtz = __pvtz
    import pulumi_alicloud.quickbi as __quickbi
    quickbi = __quickbi
    import pulumi_alicloud.quotas as __quotas
    quotas = __quotas
    import pulumi_alicloud.ram as __ram
    ram = __ram
    import pulumi_alicloud.rdc as __rdc
    rdc = __rdc
    import pulumi_alicloud.rds as __rds
    rds = __rds
    import pulumi_alicloud.realtimecompute as __realtimecompute
    realtimecompute = __realtimecompute
    import pulumi_alicloud.redis as __redis
    redis = __redis
    import pulumi_alicloud.resourcemanager as __resourcemanager
    resourcemanager = __resourcemanager
    import pulumi_alicloud.rocketmq as __rocketmq
    rocketmq = __rocketmq
    import pulumi_alicloud.ros as __ros
    ros = __ros
    import pulumi_alicloud.sae as __sae
    sae = __sae
    import pulumi_alicloud.sag as __sag
    sag = __sag
    import pulumi_alicloud.scdn as __scdn
    scdn = __scdn
    import pulumi_alicloud.schedulerx as __schedulerx
    schedulerx = __schedulerx
    import pulumi_alicloud.sddp as __sddp
    sddp = __sddp
    import pulumi_alicloud.securitycenter as __securitycenter
    securitycenter = __securitycenter
    import pulumi_alicloud.selectdb as __selectdb
    selectdb = __selectdb
    import pulumi_alicloud.servicecatalog as __servicecatalog
    servicecatalog = __servicecatalog
    import pulumi_alicloud.servicemesh as __servicemesh
    servicemesh = __servicemesh
    import pulumi_alicloud.simpleapplicationserver as __simpleapplicationserver
    simpleapplicationserver = __simpleapplicationserver
    import pulumi_alicloud.slb as __slb
    slb = __slb
    import pulumi_alicloud.sls as __sls
    sls = __sls
    import pulumi_alicloud.sms as __sms
    sms = __sms
    import pulumi_alicloud.tag as __tag
    tag = __tag
    import pulumi_alicloud.threatdetection as __threatdetection
    threatdetection = __threatdetection
    import pulumi_alicloud.tsdb as __tsdb
    tsdb = __tsdb
    import pulumi_alicloud.videosurveillance as __videosurveillance
    videosurveillance = __videosurveillance
    import pulumi_alicloud.vod as __vod
    vod = __vod
    import pulumi_alicloud.vpc as __vpc
    vpc = __vpc
    import pulumi_alicloud.vpn as __vpn
    vpn = __vpn
    import pulumi_alicloud.waf as __waf
    waf = __waf
    import pulumi_alicloud.wafv3 as __wafv3
    wafv3 = __wafv3
    import pulumi_alicloud.yundun as __yundun
    yundun = __yundun
else:
    ackone = _utilities.lazy_import('pulumi_alicloud.ackone')
    actiontrail = _utilities.lazy_import('pulumi_alicloud.actiontrail')
    adb = _utilities.lazy_import('pulumi_alicloud.adb')
    alb = _utilities.lazy_import('pulumi_alicloud.alb')
    aligreen = _utilities.lazy_import('pulumi_alicloud.aligreen')
    alikafka = _utilities.lazy_import('pulumi_alicloud.alikafka')
    amqp = _utilities.lazy_import('pulumi_alicloud.amqp')
    apigateway = _utilities.lazy_import('pulumi_alicloud.apigateway')
    arms = _utilities.lazy_import('pulumi_alicloud.arms')
    bastionhost = _utilities.lazy_import('pulumi_alicloud.bastionhost')
    bp = _utilities.lazy_import('pulumi_alicloud.bp')
    brain = _utilities.lazy_import('pulumi_alicloud.brain')
    bss = _utilities.lazy_import('pulumi_alicloud.bss')
    cas = _utilities.lazy_import('pulumi_alicloud.cas')
    cassandra = _utilities.lazy_import('pulumi_alicloud.cassandra')
    cddc = _utilities.lazy_import('pulumi_alicloud.cddc')
    cdn = _utilities.lazy_import('pulumi_alicloud.cdn')
    cen = _utilities.lazy_import('pulumi_alicloud.cen')
    cfg = _utilities.lazy_import('pulumi_alicloud.cfg')
    chatbot = _utilities.lazy_import('pulumi_alicloud.chatbot')
    clickhouse = _utilities.lazy_import('pulumi_alicloud.clickhouse')
    cloudauth = _utilities.lazy_import('pulumi_alicloud.cloudauth')
    cloudconnect = _utilities.lazy_import('pulumi_alicloud.cloudconnect')
    cloudfirewall = _utilities.lazy_import('pulumi_alicloud.cloudfirewall')
    cloudmonitor = _utilities.lazy_import('pulumi_alicloud.cloudmonitor')
    cloudsso = _utilities.lazy_import('pulumi_alicloud.cloudsso')
    cloudstoragegateway = _utilities.lazy_import('pulumi_alicloud.cloudstoragegateway')
    cms = _utilities.lazy_import('pulumi_alicloud.cms')
    compute = _utilities.lazy_import('pulumi_alicloud.compute')
    config = _utilities.lazy_import('pulumi_alicloud.config')
    cr = _utilities.lazy_import('pulumi_alicloud.cr')
    cs = _utilities.lazy_import('pulumi_alicloud.cs')
    das = _utilities.lazy_import('pulumi_alicloud.das')
    databasefilesystem = _utilities.lazy_import('pulumi_alicloud.databasefilesystem')
    databasegateway = _utilities.lazy_import('pulumi_alicloud.databasegateway')
    datahub = _utilities.lazy_import('pulumi_alicloud.datahub')
    dataworks = _utilities.lazy_import('pulumi_alicloud.dataworks')
    dbs = _utilities.lazy_import('pulumi_alicloud.dbs')
    dcdn = _utilities.lazy_import('pulumi_alicloud.dcdn')
    ddos = _utilities.lazy_import('pulumi_alicloud.ddos')
    dds = _utilities.lazy_import('pulumi_alicloud.dds')
    dfs = _utilities.lazy_import('pulumi_alicloud.dfs')
    directmail = _utilities.lazy_import('pulumi_alicloud.directmail')
    dms = _utilities.lazy_import('pulumi_alicloud.dms')
    dns = _utilities.lazy_import('pulumi_alicloud.dns')
    drds = _utilities.lazy_import('pulumi_alicloud.drds')
    dts = _utilities.lazy_import('pulumi_alicloud.dts')
    eais = _utilities.lazy_import('pulumi_alicloud.eais')
    ebs = _utilities.lazy_import('pulumi_alicloud.ebs')
    eci = _utilities.lazy_import('pulumi_alicloud.eci')
    ecp = _utilities.lazy_import('pulumi_alicloud.ecp')
    ecs = _utilities.lazy_import('pulumi_alicloud.ecs')
    edas = _utilities.lazy_import('pulumi_alicloud.edas')
    eds = _utilities.lazy_import('pulumi_alicloud.eds')
    eflo = _utilities.lazy_import('pulumi_alicloud.eflo')
    ehpc = _utilities.lazy_import('pulumi_alicloud.ehpc')
    eipanycast = _utilities.lazy_import('pulumi_alicloud.eipanycast')
    elasticsearch = _utilities.lazy_import('pulumi_alicloud.elasticsearch')
    emr = _utilities.lazy_import('pulumi_alicloud.emr')
    emrv2 = _utilities.lazy_import('pulumi_alicloud.emrv2')
    ens = _utilities.lazy_import('pulumi_alicloud.ens')
    esa = _utilities.lazy_import('pulumi_alicloud.esa')
    ess = _utilities.lazy_import('pulumi_alicloud.ess')
    eventbridge = _utilities.lazy_import('pulumi_alicloud.eventbridge')
    expressconnect = _utilities.lazy_import('pulumi_alicloud.expressconnect')
    fc = _utilities.lazy_import('pulumi_alicloud.fc')
    fnf = _utilities.lazy_import('pulumi_alicloud.fnf')
    ga = _utilities.lazy_import('pulumi_alicloud.ga')
    governance = _utilities.lazy_import('pulumi_alicloud.governance')
    gpdb = _utilities.lazy_import('pulumi_alicloud.gpdb')
    graphdatabase = _utilities.lazy_import('pulumi_alicloud.graphdatabase')
    gwlb = _utilities.lazy_import('pulumi_alicloud.gwlb')
    hbase = _utilities.lazy_import('pulumi_alicloud.hbase')
    hbr = _utilities.lazy_import('pulumi_alicloud.hbr')
    hologram = _utilities.lazy_import('pulumi_alicloud.hologram')
    imm = _utilities.lazy_import('pulumi_alicloud.imm')
    imp = _utilities.lazy_import('pulumi_alicloud.imp')
    ims = _utilities.lazy_import('pulumi_alicloud.ims')
    iot = _utilities.lazy_import('pulumi_alicloud.iot')
    kms = _utilities.lazy_import('pulumi_alicloud.kms')
    kvstore = _utilities.lazy_import('pulumi_alicloud.kvstore')
    lindorm = _utilities.lazy_import('pulumi_alicloud.lindorm')
    log = _utilities.lazy_import('pulumi_alicloud.log')
    marketplace = _utilities.lazy_import('pulumi_alicloud.marketplace')
    maxcompute = _utilities.lazy_import('pulumi_alicloud.maxcompute')
    message = _utilities.lazy_import('pulumi_alicloud.message')
    mhub = _utilities.lazy_import('pulumi_alicloud.mhub')
    mns = _utilities.lazy_import('pulumi_alicloud.mns')
    mongodb = _utilities.lazy_import('pulumi_alicloud.mongodb')
    mse = _utilities.lazy_import('pulumi_alicloud.mse')
    nas = _utilities.lazy_import('pulumi_alicloud.nas')
    nlb = _utilities.lazy_import('pulumi_alicloud.nlb')
    ocean = _utilities.lazy_import('pulumi_alicloud.ocean')
    oos = _utilities.lazy_import('pulumi_alicloud.oos')
    opensearch = _utilities.lazy_import('pulumi_alicloud.opensearch')
    oss = _utilities.lazy_import('pulumi_alicloud.oss')
    ots = _utilities.lazy_import('pulumi_alicloud.ots')
    pai = _utilities.lazy_import('pulumi_alicloud.pai')
    polardb = _utilities.lazy_import('pulumi_alicloud.polardb')
    privatelink = _utilities.lazy_import('pulumi_alicloud.privatelink')
    pvtz = _utilities.lazy_import('pulumi_alicloud.pvtz')
    quickbi = _utilities.lazy_import('pulumi_alicloud.quickbi')
    quotas = _utilities.lazy_import('pulumi_alicloud.quotas')
    ram = _utilities.lazy_import('pulumi_alicloud.ram')
    rdc = _utilities.lazy_import('pulumi_alicloud.rdc')
    rds = _utilities.lazy_import('pulumi_alicloud.rds')
    realtimecompute = _utilities.lazy_import('pulumi_alicloud.realtimecompute')
    redis = _utilities.lazy_import('pulumi_alicloud.redis')
    resourcemanager = _utilities.lazy_import('pulumi_alicloud.resourcemanager')
    rocketmq = _utilities.lazy_import('pulumi_alicloud.rocketmq')
    ros = _utilities.lazy_import('pulumi_alicloud.ros')
    sae = _utilities.lazy_import('pulumi_alicloud.sae')
    sag = _utilities.lazy_import('pulumi_alicloud.sag')
    scdn = _utilities.lazy_import('pulumi_alicloud.scdn')
    schedulerx = _utilities.lazy_import('pulumi_alicloud.schedulerx')
    sddp = _utilities.lazy_import('pulumi_alicloud.sddp')
    securitycenter = _utilities.lazy_import('pulumi_alicloud.securitycenter')
    selectdb = _utilities.lazy_import('pulumi_alicloud.selectdb')
    servicecatalog = _utilities.lazy_import('pulumi_alicloud.servicecatalog')
    servicemesh = _utilities.lazy_import('pulumi_alicloud.servicemesh')
    simpleapplicationserver = _utilities.lazy_import('pulumi_alicloud.simpleapplicationserver')
    slb = _utilities.lazy_import('pulumi_alicloud.slb')
    sls = _utilities.lazy_import('pulumi_alicloud.sls')
    sms = _utilities.lazy_import('pulumi_alicloud.sms')
    tag = _utilities.lazy_import('pulumi_alicloud.tag')
    threatdetection = _utilities.lazy_import('pulumi_alicloud.threatdetection')
    tsdb = _utilities.lazy_import('pulumi_alicloud.tsdb')
    videosurveillance = _utilities.lazy_import('pulumi_alicloud.videosurveillance')
    vod = _utilities.lazy_import('pulumi_alicloud.vod')
    vpc = _utilities.lazy_import('pulumi_alicloud.vpc')
    vpn = _utilities.lazy_import('pulumi_alicloud.vpn')
    waf = _utilities.lazy_import('pulumi_alicloud.waf')
    wafv3 = _utilities.lazy_import('pulumi_alicloud.wafv3')
    yundun = _utilities.lazy_import('pulumi_alicloud.yundun')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "alicloud",
  "mod": "ackone/cluster",
  "fqn": "pulumi_alicloud.ackone",
  "classes": {
   "alicloud:ackone/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "actiontrail/globalEventsStorageRegion",
  "fqn": "pulumi_alicloud.actiontrail",
  "classes": {
   "alicloud:actiontrail/globalEventsStorageRegion:GlobalEventsStorageRegion": "GlobalEventsStorageRegion"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "actiontrail/historyDeliveryJob",
  "fqn": "pulumi_alicloud.actiontrail",
  "classes": {
   "alicloud:actiontrail/historyDeliveryJob:HistoryDeliveryJob": "HistoryDeliveryJob"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "actiontrail/trail",
  "fqn": "pulumi_alicloud.actiontrail",
  "classes": {
   "alicloud:actiontrail/trail:Trail": "Trail"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "actiontrail/trailDeprecated",
  "fqn": "pulumi_alicloud.actiontrail",
  "classes": {
   "alicloud:actiontrail/trailDeprecated:TrailDeprecated": "TrailDeprecated"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "adb/account",
  "fqn": "pulumi_alicloud.adb",
  "classes": {
   "alicloud:adb/account:Account": "Account"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "adb/backupPolicy",
  "fqn": "pulumi_alicloud.adb",
  "classes": {
   "alicloud:adb/backupPolicy:BackupPolicy": "BackupPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "adb/cluster",
  "fqn": "pulumi_alicloud.adb",
  "classes": {
   "alicloud:adb/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "adb/connection",
  "fqn": "pulumi_alicloud.adb",
  "classes": {
   "alicloud:adb/connection:Connection": "Connection"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "adb/dBCluster",
  "fqn": "pulumi_alicloud.adb",
  "classes": {
   "alicloud:adb/dBCluster:DBCluster": "DBCluster"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "adb/dBClusterLakeVersion",
  "fqn": "pulumi_alicloud.adb",
  "classes": {
   "alicloud:adb/dBClusterLakeVersion:DBClusterLakeVersion": "DBClusterLakeVersion"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "adb/lakeAccount",
  "fqn": "pulumi_alicloud.adb",
  "classes": {
   "alicloud:adb/lakeAccount:LakeAccount": "LakeAccount"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "adb/resourceGroup",
  "fqn": "pulumi_alicloud.adb",
  "classes": {
   "alicloud:adb/resourceGroup:ResourceGroup": "ResourceGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "alb/aScript",
  "fqn": "pulumi_alicloud.alb",
  "classes": {
   "alicloud:alb/aScript:AScript": "AScript"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "alb/acl",
  "fqn": "pulumi_alicloud.alb",
  "classes": {
   "alicloud:alb/acl:Acl": "Acl"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "alb/aclEntryAttachment",
  "fqn": "pulumi_alicloud.alb",
  "classes": {
   "alicloud:alb/aclEntryAttachment:AclEntryAttachment": "AclEntryAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "alb/healthCheckTemplate",
  "fqn": "pulumi_alicloud.alb",
  "classes": {
   "alicloud:alb/healthCheckTemplate:HealthCheckTemplate": "HealthCheckTemplate"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "alb/listener",
  "fqn": "pulumi_alicloud.alb",
  "classes": {
   "alicloud:alb/listener:Listener": "Listener"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "alb/listenerAclAttachment",
  "fqn": "pulumi_alicloud.alb",
  "classes": {
   "alicloud:alb/listenerAclAttachment:ListenerAclAttachment": "ListenerAclAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "alb/listenerAdditionalCertificateAttachment",
  "fqn": "pulumi_alicloud.alb",
  "classes": {
   "alicloud:alb/listenerAdditionalCertificateAttachment:ListenerAdditionalCertificateAttachment": "ListenerAdditionalCertificateAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "alb/loadBalancer",
  "fqn": "pulumi_alicloud.alb",
  "classes": {
   "alicloud:alb/loadBalancer:LoadBalancer": "LoadBalancer"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "alb/loadBalancerCommonBandwidthPackageAttachment",
  "fqn": "pulumi_alicloud.alb",
  "classes": {
   "alicloud:alb/loadBalancerCommonBandwidthPackageAttachment:LoadBalancerCommonBandwidthPackageAttachment": "LoadBalancerCommonBandwidthPackageAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "alb/loadBalancerSecurityGroupAttachment",
  "fqn": "pulumi_alicloud.alb",
  "classes": {
   "alicloud:alb/loadBalancerSecurityGroupAttachment:LoadBalancerSecurityGroupAttachment": "LoadBalancerSecurityGroupAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "alb/rule",
  "fqn": "pulumi_alicloud.alb",
  "classes": {
   "alicloud:alb/rule:Rule": "Rule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "alb/securityPolicy",
  "fqn": "pulumi_alicloud.alb",
  "classes": {
   "alicloud:alb/securityPolicy:SecurityPolicy": "SecurityPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "alb/serverGroup",
  "fqn": "pulumi_alicloud.alb",
  "classes": {
   "alicloud:alb/serverGroup:ServerGroup": "ServerGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "aligreen/auditCallback",
  "fqn": "pulumi_alicloud.aligreen",
  "classes": {
   "alicloud:aligreen/auditCallback:AuditCallback": "AuditCallback"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "aligreen/bizType",
  "fqn": "pulumi_alicloud.aligreen",
  "classes": {
   "alicloud:aligreen/bizType:BizType": "BizType"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "aligreen/callback",
  "fqn": "pulumi_alicloud.aligreen",
  "classes": {
   "alicloud:aligreen/callback:Callback": "Callback"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "aligreen/imageLib",
  "fqn": "pulumi_alicloud.aligreen",
  "classes": {
   "alicloud:aligreen/imageLib:ImageLib": "ImageLib"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "aligreen/keywordLib",
  "fqn": "pulumi_alicloud.aligreen",
  "classes": {
   "alicloud:aligreen/keywordLib:KeywordLib": "KeywordLib"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "aligreen/ossStockTask",
  "fqn": "pulumi_alicloud.aligreen",
  "classes": {
   "alicloud:aligreen/ossStockTask:OssStockTask": "OssStockTask"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "alikafka/consumerGroup",
  "fqn": "pulumi_alicloud.alikafka",
  "classes": {
   "alicloud:alikafka/consumerGroup:ConsumerGroup": "ConsumerGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "alikafka/instance",
  "fqn": "pulumi_alicloud.alikafka",
  "classes": {
   "alicloud:alikafka/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "alikafka/instanceAllowedIpAttachment",
  "fqn": "pulumi_alicloud.alikafka",
  "classes": {
   "alicloud:alikafka/instanceAllowedIpAttachment:InstanceAllowedIpAttachment": "InstanceAllowedIpAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "alikafka/saslAcl",
  "fqn": "pulumi_alicloud.alikafka",
  "classes": {
   "alicloud:alikafka/saslAcl:SaslAcl": "SaslAcl"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "alikafka/saslUser",
  "fqn": "pulumi_alicloud.alikafka",
  "classes": {
   "alicloud:alikafka/saslUser:SaslUser": "SaslUser"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "alikafka/topic",
  "fqn": "pulumi_alicloud.alikafka",
  "classes": {
   "alicloud:alikafka/topic:Topic": "Topic"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "amqp/binding",
  "fqn": "pulumi_alicloud.amqp",
  "classes": {
   "alicloud:amqp/binding:Binding": "Binding"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "amqp/exchange",
  "fqn": "pulumi_alicloud.amqp",
  "classes": {
   "alicloud:amqp/exchange:Exchange": "Exchange"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "amqp/instance",
  "fqn": "pulumi_alicloud.amqp",
  "classes": {
   "alicloud:amqp/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "amqp/queue",
  "fqn": "pulumi_alicloud.amqp",
  "classes": {
   "alicloud:amqp/queue:Queue": "Queue"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "amqp/staticAccount",
  "fqn": "pulumi_alicloud.amqp",
  "classes": {
   "alicloud:amqp/staticAccount:StaticAccount": "StaticAccount"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "amqp/virtualHost",
  "fqn": "pulumi_alicloud.amqp",
  "classes": {
   "alicloud:amqp/virtualHost:VirtualHost": "VirtualHost"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "apigateway/accessControlList",
  "fqn": "pulumi_alicloud.apigateway",
  "classes": {
   "alicloud:apigateway/accessControlList:AccessControlList": "AccessControlList"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "apigateway/aclEntryAttachment",
  "fqn": "pulumi_alicloud.apigateway",
  "classes": {
   "alicloud:apigateway/aclEntryAttachment:AclEntryAttachment": "AclEntryAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "apigateway/api",
  "fqn": "pulumi_alicloud.apigateway",
  "classes": {
   "alicloud:apigateway/api:Api": "Api"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "apigateway/app",
  "fqn": "pulumi_alicloud.apigateway",
  "classes": {
   "alicloud:apigateway/app:App": "App"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "apigateway/appAttachment",
  "fqn": "pulumi_alicloud.apigateway",
  "classes": {
   "alicloud:apigateway/appAttachment:AppAttachment": "AppAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "apigateway/backend",
  "fqn": "pulumi_alicloud.apigateway",
  "classes": {
   "alicloud:apigateway/backend:Backend": "Backend"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "apigateway/group",
  "fqn": "pulumi_alicloud.apigateway",
  "classes": {
   "alicloud:apigateway/group:Group": "Group"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "apigateway/instance",
  "fqn": "pulumi_alicloud.apigateway",
  "classes": {
   "alicloud:apigateway/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "apigateway/instanceAclAttachment",
  "fqn": "pulumi_alicloud.apigateway",
  "classes": {
   "alicloud:apigateway/instanceAclAttachment:InstanceAclAttachment": "InstanceAclAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "apigateway/logConfig",
  "fqn": "pulumi_alicloud.apigateway",
  "classes": {
   "alicloud:apigateway/logConfig:LogConfig": "LogConfig"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "apigateway/model",
  "fqn": "pulumi_alicloud.apigateway",
  "classes": {
   "alicloud:apigateway/model:Model": "Model"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "apigateway/plugin",
  "fqn": "pulumi_alicloud.apigateway",
  "classes": {
   "alicloud:apigateway/plugin:Plugin": "Plugin"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "apigateway/pluginAttachment",
  "fqn": "pulumi_alicloud.apigateway",
  "classes": {
   "alicloud:apigateway/pluginAttachment:PluginAttachment": "PluginAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "apigateway/vpcAccess",
  "fqn": "pulumi_alicloud.apigateway",
  "classes": {
   "alicloud:apigateway/vpcAccess:VpcAccess": "VpcAccess"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "arms/addonRelease",
  "fqn": "pulumi_alicloud.arms",
  "classes": {
   "alicloud:arms/addonRelease:AddonRelease": "AddonRelease"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "arms/alertContact",
  "fqn": "pulumi_alicloud.arms",
  "classes": {
   "alicloud:arms/alertContact:AlertContact": "AlertContact"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "arms/alertContactGroup",
  "fqn": "pulumi_alicloud.arms",
  "classes": {
   "alicloud:arms/alertContactGroup:AlertContactGroup": "AlertContactGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "arms/dispatchRule",
  "fqn": "pulumi_alicloud.arms",
  "classes": {
   "alicloud:arms/dispatchRule:DispatchRule": "DispatchRule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "arms/envCustomJob",
  "fqn": "pulumi_alicloud.arms",
  "classes": {
   "alicloud:arms/envCustomJob:EnvCustomJob": "EnvCustomJob"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "arms/envFeature",
  "fqn": "pulumi_alicloud.arms",
  "classes": {
   "alicloud:arms/envFeature:EnvFeature": "EnvFeature"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "arms/envPodMonitor",
  "fqn": "pulumi_alicloud.arms",
  "classes": {
   "alicloud:arms/envPodMonitor:EnvPodMonitor": "EnvPodMonitor"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "arms/envServiceMonitor",
  "fqn": "pulumi_alicloud.arms",
  "classes": {
   "alicloud:arms/envServiceMonitor:EnvServiceMonitor": "EnvServiceMonitor"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "arms/environment",
  "fqn": "pulumi_alicloud.arms",
  "classes": {
   "alicloud:arms/environment:Environment": "Environment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "arms/grafanaWorkspace",
  "fqn": "pulumi_alicloud.arms",
  "classes": {
   "alicloud:arms/grafanaWorkspace:GrafanaWorkspace": "GrafanaWorkspace"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "arms/integrationExporter",
  "fqn": "pulumi_alicloud.arms",
  "classes": {
   "alicloud:arms/integrationExporter:IntegrationExporter": "IntegrationExporter"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "arms/prometheus",
  "fqn": "pulumi_alicloud.arms",
  "classes": {
   "alicloud:arms/prometheus:Prometheus": "Prometheus"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "arms/prometheusAlertRule",
  "fqn": "pulumi_alicloud.arms",
  "classes": {
   "alicloud:arms/prometheusAlertRule:PrometheusAlertRule": "PrometheusAlertRule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "arms/prometheusMonitoring",
  "fqn": "pulumi_alicloud.arms",
  "classes": {
   "alicloud:arms/prometheusMonitoring:PrometheusMonitoring": "PrometheusMonitoring"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "arms/remoteWrite",
  "fqn": "pulumi_alicloud.arms",
  "classes": {
   "alicloud:arms/remoteWrite:RemoteWrite": "RemoteWrite"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "arms/syntheticTask",
  "fqn": "pulumi_alicloud.arms",
  "classes": {
   "alicloud:arms/syntheticTask:SyntheticTask": "SyntheticTask"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "bastionhost/host",
  "fqn": "pulumi_alicloud.bastionhost",
  "classes": {
   "alicloud:bastionhost/host:Host": "Host"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "bastionhost/hostAccount",
  "fqn": "pulumi_alicloud.bastionhost",
  "classes": {
   "alicloud:bastionhost/hostAccount:HostAccount": "HostAccount"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "bastionhost/hostAccountShareKeyAttachment",
  "fqn": "pulumi_alicloud.bastionhost",
  "classes": {
   "alicloud:bastionhost/hostAccountShareKeyAttachment:HostAccountShareKeyAttachment": "HostAccountShareKeyAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "bastionhost/hostAccountUserAttachment",
  "fqn": "pulumi_alicloud.bastionhost",
  "classes": {
   "alicloud:bastionhost/hostAccountUserAttachment:HostAccountUserAttachment": "HostAccountUserAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "bastionhost/hostAccountUserGroupAttachment",
  "fqn": "pulumi_alicloud.bastionhost",
  "classes": {
   "alicloud:bastionhost/hostAccountUserGroupAttachment:HostAccountUserGroupAttachment": "HostAccountUserGroupAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "bastionhost/hostAttachment",
  "fqn": "pulumi_alicloud.bastionhost",
  "classes": {
   "alicloud:bastionhost/hostAttachment:HostAttachment": "HostAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "bastionhost/hostGroup",
  "fqn": "pulumi_alicloud.bastionhost",
  "classes": {
   "alicloud:bastionhost/hostGroup:HostGroup": "HostGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "bastionhost/hostGroupAccountUserAttachment",
  "fqn": "pulumi_alicloud.bastionhost",
  "classes": {
   "alicloud:bastionhost/hostGroupAccountUserAttachment:HostGroupAccountUserAttachment": "HostGroupAccountUserAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "bastionhost/hostGroupAccountUserGroupAttachment",
  "fqn": "pulumi_alicloud.bastionhost",
  "classes": {
   "alicloud:bastionhost/hostGroupAccountUserGroupAttachment:HostGroupAccountUserGroupAttachment": "HostGroupAccountUserGroupAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "bastionhost/hostShareKey",
  "fqn": "pulumi_alicloud.bastionhost",
  "classes": {
   "alicloud:bastionhost/hostShareKey:HostShareKey": "HostShareKey"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "bastionhost/instance",
  "fqn": "pulumi_alicloud.bastionhost",
  "classes": {
   "alicloud:bastionhost/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "bastionhost/user",
  "fqn": "pulumi_alicloud.bastionhost",
  "classes": {
   "alicloud:bastionhost/user:User": "User"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "bastionhost/userAttachment",
  "fqn": "pulumi_alicloud.bastionhost",
  "classes": {
   "alicloud:bastionhost/userAttachment:UserAttachment": "UserAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "bastionhost/userGroup",
  "fqn": "pulumi_alicloud.bastionhost",
  "classes": {
   "alicloud:bastionhost/userGroup:UserGroup": "UserGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "bp/studioApplication",
  "fqn": "pulumi_alicloud.bp",
  "classes": {
   "alicloud:bp/studioApplication:StudioApplication": "StudioApplication"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "brain/industrialPidLoop",
  "fqn": "pulumi_alicloud.brain",
  "classes": {
   "alicloud:brain/industrialPidLoop:IndustrialPidLoop": "IndustrialPidLoop"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "brain/industrialPidOrganization",
  "fqn": "pulumi_alicloud.brain",
  "classes": {
   "alicloud:brain/industrialPidOrganization:IndustrialPidOrganization": "IndustrialPidOrganization"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "brain/industrialPidProject",
  "fqn": "pulumi_alicloud.brain",
  "classes": {
   "alicloud:brain/industrialPidProject:IndustrialPidProject": "IndustrialPidProject"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cas/certificate",
  "fqn": "pulumi_alicloud.cas",
  "classes": {
   "alicloud:cas/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cas/serviceCertificate",
  "fqn": "pulumi_alicloud.cas",
  "classes": {
   "alicloud:cas/serviceCertificate:ServiceCertificate": "ServiceCertificate"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cassandra/backupPlan",
  "fqn": "pulumi_alicloud.cassandra",
  "classes": {
   "alicloud:cassandra/backupPlan:BackupPlan": "BackupPlan"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cassandra/cluster",
  "fqn": "pulumi_alicloud.cassandra",
  "classes": {
   "alicloud:cassandra/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cassandra/dataCenter",
  "fqn": "pulumi_alicloud.cassandra",
  "classes": {
   "alicloud:cassandra/dataCenter:DataCenter": "DataCenter"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cddc/dedicatedHost",
  "fqn": "pulumi_alicloud.cddc",
  "classes": {
   "alicloud:cddc/dedicatedHost:DedicatedHost": "DedicatedHost"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cddc/dedicatedHostAccount",
  "fqn": "pulumi_alicloud.cddc",
  "classes": {
   "alicloud:cddc/dedicatedHostAccount:DedicatedHostAccount": "DedicatedHostAccount"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cddc/dedicatedHostGroup",
  "fqn": "pulumi_alicloud.cddc",
  "classes": {
   "alicloud:cddc/dedicatedHostGroup:DedicatedHostGroup": "DedicatedHostGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cddc/dedicatedPropreHost",
  "fqn": "pulumi_alicloud.cddc",
  "classes": {
   "alicloud:cddc/dedicatedPropreHost:DedicatedPropreHost": "DedicatedPropreHost"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cdn/domain",
  "fqn": "pulumi_alicloud.cdn",
  "classes": {
   "alicloud:cdn/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cdn/domainConfig",
  "fqn": "pulumi_alicloud.cdn",
  "classes": {
   "alicloud:cdn/domainConfig:DomainConfig": "DomainConfig"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cdn/domainNew",
  "fqn": "pulumi_alicloud.cdn",
  "classes": {
   "alicloud:cdn/domainNew:DomainNew": "DomainNew"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cdn/fcTrigger",
  "fqn": "pulumi_alicloud.cdn",
  "classes": {
   "alicloud:cdn/fcTrigger:FcTrigger": "FcTrigger"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cdn/realTimeLogDelivery",
  "fqn": "pulumi_alicloud.cdn",
  "classes": {
   "alicloud:cdn/realTimeLogDelivery:RealTimeLogDelivery": "RealTimeLogDelivery"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/bandwidthLimit",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/bandwidthLimit:BandwidthLimit": "BandwidthLimit"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/bandwidthPackage",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/bandwidthPackage:BandwidthPackage": "BandwidthPackage"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/bandwidthPackageAttachment",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/bandwidthPackageAttachment:BandwidthPackageAttachment": "BandwidthPackageAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/childInstanceRouteEntryToAttachment",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/childInstanceRouteEntryToAttachment:ChildInstanceRouteEntryToAttachment": "ChildInstanceRouteEntryToAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/flowLog",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/flowLog:FlowLog": "FlowLog"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/instance",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/instanceAttachment",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/instanceAttachment:InstanceAttachment": "InstanceAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/instanceGrant",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/instanceGrant:InstanceGrant": "InstanceGrant"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/interRegionTrafficQosPolicy",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/interRegionTrafficQosPolicy:InterRegionTrafficQosPolicy": "InterRegionTrafficQosPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/interRegionTrafficQosQueue",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/interRegionTrafficQosQueue:InterRegionTrafficQosQueue": "InterRegionTrafficQosQueue"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/privateZone",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/privateZone:PrivateZone": "PrivateZone"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/routeEntry",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/routeEntry:RouteEntry": "RouteEntry"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/routeMap",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/routeMap:RouteMap": "RouteMap"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/routeService",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/routeService:RouteService": "RouteService"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/trafficMarkingPolicy",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/trafficMarkingPolicy:TrafficMarkingPolicy": "TrafficMarkingPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/transitRouteTableAggregation",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/transitRouteTableAggregation:TransitRouteTableAggregation": "TransitRouteTableAggregation"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/transitRouter",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/transitRouter:TransitRouter": "TransitRouter"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/transitRouterCidr",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/transitRouterCidr:TransitRouterCidr": "TransitRouterCidr"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/transitRouterEcrAttachment",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/transitRouterEcrAttachment:TransitRouterEcrAttachment": "TransitRouterEcrAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/transitRouterGrantAttachment",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/transitRouterGrantAttachment:TransitRouterGrantAttachment": "TransitRouterGrantAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/transitRouterMulticastDomain",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/transitRouterMulticastDomain:TransitRouterMulticastDomain": "TransitRouterMulticastDomain"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/transitRouterMulticastDomainAssociation",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/transitRouterMulticastDomainAssociation:TransitRouterMulticastDomainAssociation": "TransitRouterMulticastDomainAssociation"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/transitRouterMulticastDomainMember",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/transitRouterMulticastDomainMember:TransitRouterMulticastDomainMember": "TransitRouterMulticastDomainMember"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/transitRouterMulticastDomainPeerMember",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/transitRouterMulticastDomainPeerMember:TransitRouterMulticastDomainPeerMember": "TransitRouterMulticastDomainPeerMember"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/transitRouterMulticastDomainSource",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/transitRouterMulticastDomainSource:TransitRouterMulticastDomainSource": "TransitRouterMulticastDomainSource"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/transitRouterPeerAttachment",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/transitRouterPeerAttachment:TransitRouterPeerAttachment": "TransitRouterPeerAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/transitRouterPrefixListAssociation",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/transitRouterPrefixListAssociation:TransitRouterPrefixListAssociation": "TransitRouterPrefixListAssociation"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/transitRouterRouteEntry",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/transitRouterRouteEntry:TransitRouterRouteEntry": "TransitRouterRouteEntry"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/transitRouterRouteTable",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/transitRouterRouteTable:TransitRouterRouteTable": "TransitRouterRouteTable"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/transitRouterRouteTableAssociation",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/transitRouterRouteTableAssociation:TransitRouterRouteTableAssociation": "TransitRouterRouteTableAssociation"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/transitRouterRouteTablePropagation",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/transitRouterRouteTablePropagation:TransitRouterRouteTablePropagation": "TransitRouterRouteTablePropagation"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/transitRouterVbrAttachment",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/transitRouterVbrAttachment:TransitRouterVbrAttachment": "TransitRouterVbrAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/transitRouterVpcAttachment",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/transitRouterVpcAttachment:TransitRouterVpcAttachment": "TransitRouterVpcAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/transitRouterVpnAttachment",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/transitRouterVpnAttachment:TransitRouterVpnAttachment": "TransitRouterVpnAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cen/vbrHealthCheck",
  "fqn": "pulumi_alicloud.cen",
  "classes": {
   "alicloud:cen/vbrHealthCheck:VbrHealthCheck": "VbrHealthCheck"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cfg/aggregateCompliancePack",
  "fqn": "pulumi_alicloud.cfg",
  "classes": {
   "alicloud:cfg/aggregateCompliancePack:AggregateCompliancePack": "AggregateCompliancePack"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cfg/aggregateConfigRule",
  "fqn": "pulumi_alicloud.cfg",
  "classes": {
   "alicloud:cfg/aggregateConfigRule:AggregateConfigRule": "AggregateConfigRule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cfg/aggregateDelivery",
  "fqn": "pulumi_alicloud.cfg",
  "classes": {
   "alicloud:cfg/aggregateDelivery:AggregateDelivery": "AggregateDelivery"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cfg/aggregator",
  "fqn": "pulumi_alicloud.cfg",
  "classes": {
   "alicloud:cfg/aggregator:Aggregator": "Aggregator"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cfg/compliancePack",
  "fqn": "pulumi_alicloud.cfg",
  "classes": {
   "alicloud:cfg/compliancePack:CompliancePack": "CompliancePack"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cfg/configurationRecorder",
  "fqn": "pulumi_alicloud.cfg",
  "classes": {
   "alicloud:cfg/configurationRecorder:ConfigurationRecorder": "ConfigurationRecorder"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cfg/delivery",
  "fqn": "pulumi_alicloud.cfg",
  "classes": {
   "alicloud:cfg/delivery:Delivery": "Delivery"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cfg/deliveryChannel",
  "fqn": "pulumi_alicloud.cfg",
  "classes": {
   "alicloud:cfg/deliveryChannel:DeliveryChannel": "DeliveryChannel"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cfg/remediation",
  "fqn": "pulumi_alicloud.cfg",
  "classes": {
   "alicloud:cfg/remediation:Remediation": "Remediation"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cfg/rule",
  "fqn": "pulumi_alicloud.cfg",
  "classes": {
   "alicloud:cfg/rule:Rule": "Rule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "chatbot/publishTask",
  "fqn": "pulumi_alicloud.chatbot",
  "classes": {
   "alicloud:chatbot/publishTask:PublishTask": "PublishTask"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "clickhouse/account",
  "fqn": "pulumi_alicloud.clickhouse",
  "classes": {
   "alicloud:clickhouse/account:Account": "Account"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "clickhouse/backupPolicy",
  "fqn": "pulumi_alicloud.clickhouse",
  "classes": {
   "alicloud:clickhouse/backupPolicy:BackupPolicy": "BackupPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "clickhouse/dbCluster",
  "fqn": "pulumi_alicloud.clickhouse",
  "classes": {
   "alicloud:clickhouse/dbCluster:DbCluster": "DbCluster"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudauth/faceConfig",
  "fqn": "pulumi_alicloud.cloudauth",
  "classes": {
   "alicloud:cloudauth/faceConfig:FaceConfig": "FaceConfig"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudconnect/network",
  "fqn": "pulumi_alicloud.cloudconnect",
  "classes": {
   "alicloud:cloudconnect/network:Network": "Network"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudconnect/networkAttachment",
  "fqn": "pulumi_alicloud.cloudconnect",
  "classes": {
   "alicloud:cloudconnect/networkAttachment:NetworkAttachment": "NetworkAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudconnect/networkGrant",
  "fqn": "pulumi_alicloud.cloudconnect",
  "classes": {
   "alicloud:cloudconnect/networkGrant:NetworkGrant": "NetworkGrant"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudfirewall/addressBook",
  "fqn": "pulumi_alicloud.cloudfirewall",
  "classes": {
   "alicloud:cloudfirewall/addressBook:AddressBook": "AddressBook"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudfirewall/controlPolicy",
  "fqn": "pulumi_alicloud.cloudfirewall",
  "classes": {
   "alicloud:cloudfirewall/controlPolicy:ControlPolicy": "ControlPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudfirewall/controlPolicyOrder",
  "fqn": "pulumi_alicloud.cloudfirewall",
  "classes": {
   "alicloud:cloudfirewall/controlPolicyOrder:ControlPolicyOrder": "ControlPolicyOrder"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudfirewall/firewallVpcFirewall",
  "fqn": "pulumi_alicloud.cloudfirewall",
  "classes": {
   "alicloud:cloudfirewall/firewallVpcFirewall:FirewallVpcFirewall": "FirewallVpcFirewall"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudfirewall/firewallVpcFirewallCen",
  "fqn": "pulumi_alicloud.cloudfirewall",
  "classes": {
   "alicloud:cloudfirewall/firewallVpcFirewallCen:FirewallVpcFirewallCen": "FirewallVpcFirewallCen"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudfirewall/firewallVpcFirewallControlPolicy",
  "fqn": "pulumi_alicloud.cloudfirewall",
  "classes": {
   "alicloud:cloudfirewall/firewallVpcFirewallControlPolicy:FirewallVpcFirewallControlPolicy": "FirewallVpcFirewallControlPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudfirewall/instance",
  "fqn": "pulumi_alicloud.cloudfirewall",
  "classes": {
   "alicloud:cloudfirewall/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudfirewall/instanceMember",
  "fqn": "pulumi_alicloud.cloudfirewall",
  "classes": {
   "alicloud:cloudfirewall/instanceMember:InstanceMember": "InstanceMember"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudfirewall/natFirewall",
  "fqn": "pulumi_alicloud.cloudfirewall",
  "classes": {
   "alicloud:cloudfirewall/natFirewall:NatFirewall": "NatFirewall"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudfirewall/natFirewallControlPolicy",
  "fqn": "pulumi_alicloud.cloudfirewall",
  "classes": {
   "alicloud:cloudfirewall/natFirewallControlPolicy:NatFirewallControlPolicy": "NatFirewallControlPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudfirewall/vpcCenTrFirewall",
  "fqn": "pulumi_alicloud.cloudfirewall",
  "classes": {
   "alicloud:cloudfirewall/vpcCenTrFirewall:VpcCenTrFirewall": "VpcCenTrFirewall"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudmonitor/serviceBasicPublic",
  "fqn": "pulumi_alicloud.cloudmonitor",
  "classes": {
   "alicloud:cloudmonitor/serviceBasicPublic:ServiceBasicPublic": "ServiceBasicPublic"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudmonitor/serviceEnterprisePublic",
  "fqn": "pulumi_alicloud.cloudmonitor",
  "classes": {
   "alicloud:cloudmonitor/serviceEnterprisePublic:ServiceEnterprisePublic": "ServiceEnterprisePublic"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudmonitor/serviceGroupMonitoringAgentProcess",
  "fqn": "pulumi_alicloud.cloudmonitor",
  "classes": {
   "alicloud:cloudmonitor/serviceGroupMonitoringAgentProcess:ServiceGroupMonitoringAgentProcess": "ServiceGroupMonitoringAgentProcess"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudmonitor/serviceHybridDoubleWrite",
  "fqn": "pulumi_alicloud.cloudmonitor",
  "classes": {
   "alicloud:cloudmonitor/serviceHybridDoubleWrite:ServiceHybridDoubleWrite": "ServiceHybridDoubleWrite"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudmonitor/serviceMonitoringAgentProcess",
  "fqn": "pulumi_alicloud.cloudmonitor",
  "classes": {
   "alicloud:cloudmonitor/serviceMonitoringAgentProcess:ServiceMonitoringAgentProcess": "ServiceMonitoringAgentProcess"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudsso/accessConfiguration",
  "fqn": "pulumi_alicloud.cloudsso",
  "classes": {
   "alicloud:cloudsso/accessConfiguration:AccessConfiguration": "AccessConfiguration"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudsso/accessConfigurationProvisioning",
  "fqn": "pulumi_alicloud.cloudsso",
  "classes": {
   "alicloud:cloudsso/accessConfigurationProvisioning:AccessConfigurationProvisioning": "AccessConfigurationProvisioning"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudsso/accessManagement",
  "fqn": "pulumi_alicloud.cloudsso",
  "classes": {
   "alicloud:cloudsso/accessManagement:AccessManagement": "AccessManagement"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudsso/directory",
  "fqn": "pulumi_alicloud.cloudsso",
  "classes": {
   "alicloud:cloudsso/directory:Directory": "Directory"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudsso/group",
  "fqn": "pulumi_alicloud.cloudsso",
  "classes": {
   "alicloud:cloudsso/group:Group": "Group"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudsso/scimServerCredential",
  "fqn": "pulumi_alicloud.cloudsso",
  "classes": {
   "alicloud:cloudsso/scimServerCredential:ScimServerCredential": "ScimServerCredential"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudsso/user",
  "fqn": "pulumi_alicloud.cloudsso",
  "classes": {
   "alicloud:cloudsso/user:User": "User"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudsso/userAttachment",
  "fqn": "pulumi_alicloud.cloudsso",
  "classes": {
   "alicloud:cloudsso/userAttachment:UserAttachment": "UserAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudstoragegateway/expressSync",
  "fqn": "pulumi_alicloud.cloudstoragegateway",
  "classes": {
   "alicloud:cloudstoragegateway/expressSync:ExpressSync": "ExpressSync"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudstoragegateway/expressSyncShareAttachment",
  "fqn": "pulumi_alicloud.cloudstoragegateway",
  "classes": {
   "alicloud:cloudstoragegateway/expressSyncShareAttachment:ExpressSyncShareAttachment": "ExpressSyncShareAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudstoragegateway/gateway",
  "fqn": "pulumi_alicloud.cloudstoragegateway",
  "classes": {
   "alicloud:cloudstoragegateway/gateway:Gateway": "Gateway"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudstoragegateway/gatewayBlockVolume",
  "fqn": "pulumi_alicloud.cloudstoragegateway",
  "classes": {
   "alicloud:cloudstoragegateway/gatewayBlockVolume:GatewayBlockVolume": "GatewayBlockVolume"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudstoragegateway/gatewayCacheDisk",
  "fqn": "pulumi_alicloud.cloudstoragegateway",
  "classes": {
   "alicloud:cloudstoragegateway/gatewayCacheDisk:GatewayCacheDisk": "GatewayCacheDisk"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudstoragegateway/gatewayFileShare",
  "fqn": "pulumi_alicloud.cloudstoragegateway",
  "classes": {
   "alicloud:cloudstoragegateway/gatewayFileShare:GatewayFileShare": "GatewayFileShare"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudstoragegateway/gatewayLogging",
  "fqn": "pulumi_alicloud.cloudstoragegateway",
  "classes": {
   "alicloud:cloudstoragegateway/gatewayLogging:GatewayLogging": "GatewayLogging"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudstoragegateway/gatewaySmbUser",
  "fqn": "pulumi_alicloud.cloudstoragegateway",
  "classes": {
   "alicloud:cloudstoragegateway/gatewaySmbUser:GatewaySmbUser": "GatewaySmbUser"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cloudstoragegateway/storageBundle",
  "fqn": "pulumi_alicloud.cloudstoragegateway",
  "classes": {
   "alicloud:cloudstoragegateway/storageBundle:StorageBundle": "StorageBundle"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cms/alarm",
  "fqn": "pulumi_alicloud.cms",
  "classes": {
   "alicloud:cms/alarm:Alarm": "Alarm"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cms/alarmContact",
  "fqn": "pulumi_alicloud.cms",
  "classes": {
   "alicloud:cms/alarmContact:AlarmContact": "AlarmContact"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cms/alarmContactGroup",
  "fqn": "pulumi_alicloud.cms",
  "classes": {
   "alicloud:cms/alarmContactGroup:AlarmContactGroup": "AlarmContactGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cms/dynamicTagGroup",
  "fqn": "pulumi_alicloud.cms",
  "classes": {
   "alicloud:cms/dynamicTagGroup:DynamicTagGroup": "DynamicTagGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cms/eventRule",
  "fqn": "pulumi_alicloud.cms",
  "classes": {
   "alicloud:cms/eventRule:EventRule": "EventRule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cms/groupMetricRule",
  "fqn": "pulumi_alicloud.cms",
  "classes": {
   "alicloud:cms/groupMetricRule:GroupMetricRule": "GroupMetricRule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cms/hybridMonitorFcTask",
  "fqn": "pulumi_alicloud.cms",
  "classes": {
   "alicloud:cms/hybridMonitorFcTask:HybridMonitorFcTask": "HybridMonitorFcTask"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cms/hybridMonitorSlsTask",
  "fqn": "pulumi_alicloud.cms",
  "classes": {
   "alicloud:cms/hybridMonitorSlsTask:HybridMonitorSlsTask": "HybridMonitorSlsTask"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cms/metricRuleBlackList",
  "fqn": "pulumi_alicloud.cms",
  "classes": {
   "alicloud:cms/metricRuleBlackList:MetricRuleBlackList": "MetricRuleBlackList"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cms/metricRuleTemplate",
  "fqn": "pulumi_alicloud.cms",
  "classes": {
   "alicloud:cms/metricRuleTemplate:MetricRuleTemplate": "MetricRuleTemplate"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cms/monitorGroup",
  "fqn": "pulumi_alicloud.cms",
  "classes": {
   "alicloud:cms/monitorGroup:MonitorGroup": "MonitorGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cms/monitorGroupInstances",
  "fqn": "pulumi_alicloud.cms",
  "classes": {
   "alicloud:cms/monitorGroupInstances:MonitorGroupInstances": "MonitorGroupInstances"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cms/namespace",
  "fqn": "pulumi_alicloud.cms",
  "classes": {
   "alicloud:cms/namespace:Namespace": "Namespace"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cms/siteMonitor",
  "fqn": "pulumi_alicloud.cms",
  "classes": {
   "alicloud:cms/siteMonitor:SiteMonitor": "SiteMonitor"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cms/slsGroup",
  "fqn": "pulumi_alicloud.cms",
  "classes": {
   "alicloud:cms/slsGroup:SlsGroup": "SlsGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "compute/nestServiceInstance",
  "fqn": "pulumi_alicloud.compute",
  "classes": {
   "alicloud:compute/nestServiceInstance:NestServiceInstance": "NestServiceInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cr/chain",
  "fqn": "pulumi_alicloud.cr",
  "classes": {
   "alicloud:cr/chain:Chain": "Chain"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cr/chartNamespace",
  "fqn": "pulumi_alicloud.cr",
  "classes": {
   "alicloud:cr/chartNamespace:ChartNamespace": "ChartNamespace"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cr/chartRepository",
  "fqn": "pulumi_alicloud.cr",
  "classes": {
   "alicloud:cr/chartRepository:ChartRepository": "ChartRepository"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cr/endpointAclPolicy",
  "fqn": "pulumi_alicloud.cr",
  "classes": {
   "alicloud:cr/endpointAclPolicy:EndpointAclPolicy": "EndpointAclPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cr/namespace",
  "fqn": "pulumi_alicloud.cr",
  "classes": {
   "alicloud:cr/namespace:Namespace": "Namespace"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cr/registryEnterpriseInstance",
  "fqn": "pulumi_alicloud.cr",
  "classes": {
   "alicloud:cr/registryEnterpriseInstance:RegistryEnterpriseInstance": "RegistryEnterpriseInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cr/repo",
  "fqn": "pulumi_alicloud.cr",
  "classes": {
   "alicloud:cr/repo:Repo": "Repo"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cr/vpcEndpointLinkedVpc",
  "fqn": "pulumi_alicloud.cr",
  "classes": {
   "alicloud:cr/vpcEndpointLinkedVpc:VpcEndpointLinkedVpc": "VpcEndpointLinkedVpc"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cs/application",
  "fqn": "pulumi_alicloud.cs",
  "classes": {
   "alicloud:cs/application:Application": "Application"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cs/autoscalingConfig",
  "fqn": "pulumi_alicloud.cs",
  "classes": {
   "alicloud:cs/autoscalingConfig:AutoscalingConfig": "AutoscalingConfig"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cs/cluster",
  "fqn": "pulumi_alicloud.cs",
  "classes": {
   "alicloud:cs/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cs/edgeKubernetes",
  "fqn": "pulumi_alicloud.cs",
  "classes": {
   "alicloud:cs/edgeKubernetes:EdgeKubernetes": "EdgeKubernetes"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cs/kubernetes",
  "fqn": "pulumi_alicloud.cs",
  "classes": {
   "alicloud:cs/kubernetes:Kubernetes": "Kubernetes"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cs/kubernetesAddon",
  "fqn": "pulumi_alicloud.cs",
  "classes": {
   "alicloud:cs/kubernetesAddon:KubernetesAddon": "KubernetesAddon"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cs/kubernetesAutoscaler",
  "fqn": "pulumi_alicloud.cs",
  "classes": {
   "alicloud:cs/kubernetesAutoscaler:KubernetesAutoscaler": "KubernetesAutoscaler"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cs/kubernetesPermission",
  "fqn": "pulumi_alicloud.cs",
  "classes": {
   "alicloud:cs/kubernetesPermission:KubernetesPermission": "KubernetesPermission"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cs/managedKubernetes",
  "fqn": "pulumi_alicloud.cs",
  "classes": {
   "alicloud:cs/managedKubernetes:ManagedKubernetes": "ManagedKubernetes"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cs/nodePool",
  "fqn": "pulumi_alicloud.cs",
  "classes": {
   "alicloud:cs/nodePool:NodePool": "NodePool"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cs/registryEnterpriseNamespace",
  "fqn": "pulumi_alicloud.cs",
  "classes": {
   "alicloud:cs/registryEnterpriseNamespace:RegistryEnterpriseNamespace": "RegistryEnterpriseNamespace"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cs/registryEnterpriseRepo",
  "fqn": "pulumi_alicloud.cs",
  "classes": {
   "alicloud:cs/registryEnterpriseRepo:RegistryEnterpriseRepo": "RegistryEnterpriseRepo"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cs/registryEnterpriseSyncRule",
  "fqn": "pulumi_alicloud.cs",
  "classes": {
   "alicloud:cs/registryEnterpriseSyncRule:RegistryEnterpriseSyncRule": "RegistryEnterpriseSyncRule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cs/serverlessKubernetes",
  "fqn": "pulumi_alicloud.cs",
  "classes": {
   "alicloud:cs/serverlessKubernetes:ServerlessKubernetes": "ServerlessKubernetes"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "cs/swarm",
  "fqn": "pulumi_alicloud.cs",
  "classes": {
   "alicloud:cs/swarm:Swarm": "Swarm"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "das/switchDasPro",
  "fqn": "pulumi_alicloud.das",
  "classes": {
   "alicloud:das/switchDasPro:SwitchDasPro": "SwitchDasPro"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "databasefilesystem/autoSnapShotPolicy",
  "fqn": "pulumi_alicloud.databasefilesystem",
  "classes": {
   "alicloud:databasefilesystem/autoSnapShotPolicy:AutoSnapShotPolicy": "AutoSnapShotPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "databasefilesystem/instance",
  "fqn": "pulumi_alicloud.databasefilesystem",
  "classes": {
   "alicloud:databasefilesystem/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "databasefilesystem/instanceAttachment",
  "fqn": "pulumi_alicloud.databasefilesystem",
  "classes": {
   "alicloud:databasefilesystem/instanceAttachment:InstanceAttachment": "InstanceAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "databasefilesystem/serviceLinkedRole",
  "fqn": "pulumi_alicloud.databasefilesystem",
  "classes": {
   "alicloud:databasefilesystem/serviceLinkedRole:ServiceLinkedRole": "ServiceLinkedRole"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "databasefilesystem/snapshot",
  "fqn": "pulumi_alicloud.databasefilesystem",
  "classes": {
   "alicloud:databasefilesystem/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "databasegateway/gateway",
  "fqn": "pulumi_alicloud.databasegateway",
  "classes": {
   "alicloud:databasegateway/gateway:Gateway": "Gateway"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "datahub/project",
  "fqn": "pulumi_alicloud.datahub",
  "classes": {
   "alicloud:datahub/project:Project": "Project"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "datahub/subscription",
  "fqn": "pulumi_alicloud.datahub",
  "classes": {
   "alicloud:datahub/subscription:Subscription": "Subscription"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "datahub/topic",
  "fqn": "pulumi_alicloud.datahub",
  "classes": {
   "alicloud:datahub/topic:Topic": "Topic"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dataworks/folder",
  "fqn": "pulumi_alicloud.dataworks",
  "classes": {
   "alicloud:dataworks/folder:Folder": "Folder"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dataworks/project",
  "fqn": "pulumi_alicloud.dataworks",
  "classes": {
   "alicloud:dataworks/project:Project": "Project"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dbs/backupPlan",
  "fqn": "pulumi_alicloud.dbs",
  "classes": {
   "alicloud:dbs/backupPlan:BackupPlan": "BackupPlan"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dcdn/domain",
  "fqn": "pulumi_alicloud.dcdn",
  "classes": {
   "alicloud:dcdn/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dcdn/domainConfig",
  "fqn": "pulumi_alicloud.dcdn",
  "classes": {
   "alicloud:dcdn/domainConfig:DomainConfig": "DomainConfig"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dcdn/er",
  "fqn": "pulumi_alicloud.dcdn",
  "classes": {
   "alicloud:dcdn/er:Er": "Er"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dcdn/ipaDomain",
  "fqn": "pulumi_alicloud.dcdn",
  "classes": {
   "alicloud:dcdn/ipaDomain:IpaDomain": "IpaDomain"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dcdn/kv",
  "fqn": "pulumi_alicloud.dcdn",
  "classes": {
   "alicloud:dcdn/kv:Kv": "Kv"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dcdn/kvNamespace",
  "fqn": "pulumi_alicloud.dcdn",
  "classes": {
   "alicloud:dcdn/kvNamespace:KvNamespace": "KvNamespace"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dcdn/wafDomain",
  "fqn": "pulumi_alicloud.dcdn",
  "classes": {
   "alicloud:dcdn/wafDomain:WafDomain": "WafDomain"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dcdn/wafPolicy",
  "fqn": "pulumi_alicloud.dcdn",
  "classes": {
   "alicloud:dcdn/wafPolicy:WafPolicy": "WafPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dcdn/wafPolicyDomainAttachment",
  "fqn": "pulumi_alicloud.dcdn",
  "classes": {
   "alicloud:dcdn/wafPolicyDomainAttachment:WafPolicyDomainAttachment": "WafPolicyDomainAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dcdn/wafRule",
  "fqn": "pulumi_alicloud.dcdn",
  "classes": {
   "alicloud:dcdn/wafRule:WafRule": "WafRule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ddos/basicDefenseThreshold",
  "fqn": "pulumi_alicloud.ddos",
  "classes": {
   "alicloud:ddos/basicDefenseThreshold:BasicDefenseThreshold": "BasicDefenseThreshold"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ddos/basicThreshold",
  "fqn": "pulumi_alicloud.ddos",
  "classes": {
   "alicloud:ddos/basicThreshold:BasicThreshold": "BasicThreshold"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ddos/bgpIp",
  "fqn": "pulumi_alicloud.ddos",
  "classes": {
   "alicloud:ddos/bgpIp:BgpIp": "BgpIp"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ddos/bgpPolicy",
  "fqn": "pulumi_alicloud.ddos",
  "classes": {
   "alicloud:ddos/bgpPolicy:BgpPolicy": "BgpPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ddos/ddosBgpInstance",
  "fqn": "pulumi_alicloud.ddos",
  "classes": {
   "alicloud:ddos/ddosBgpInstance:DdosBgpInstance": "DdosBgpInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ddos/ddosCooInstance",
  "fqn": "pulumi_alicloud.ddos",
  "classes": {
   "alicloud:ddos/ddosCooInstance:DdosCooInstance": "DdosCooInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ddos/domainResource",
  "fqn": "pulumi_alicloud.ddos",
  "classes": {
   "alicloud:ddos/domainResource:DomainResource": "DomainResource"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ddos/port",
  "fqn": "pulumi_alicloud.ddos",
  "classes": {
   "alicloud:ddos/port:Port": "Port"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ddos/schedulerRule",
  "fqn": "pulumi_alicloud.ddos",
  "classes": {
   "alicloud:ddos/schedulerRule:SchedulerRule": "SchedulerRule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dfs/accessGroup",
  "fqn": "pulumi_alicloud.dfs",
  "classes": {
   "alicloud:dfs/accessGroup:AccessGroup": "AccessGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dfs/accessRule",
  "fqn": "pulumi_alicloud.dfs",
  "classes": {
   "alicloud:dfs/accessRule:AccessRule": "AccessRule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dfs/fileSystem",
  "fqn": "pulumi_alicloud.dfs",
  "classes": {
   "alicloud:dfs/fileSystem:FileSystem": "FileSystem"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dfs/mountPoint",
  "fqn": "pulumi_alicloud.dfs",
  "classes": {
   "alicloud:dfs/mountPoint:MountPoint": "MountPoint"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dfs/vscMountPoint",
  "fqn": "pulumi_alicloud.dfs",
  "classes": {
   "alicloud:dfs/vscMountPoint:VscMountPoint": "VscMountPoint"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "directmail/domain",
  "fqn": "pulumi_alicloud.directmail",
  "classes": {
   "alicloud:directmail/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "directmail/mailAddress",
  "fqn": "pulumi_alicloud.directmail",
  "classes": {
   "alicloud:directmail/mailAddress:MailAddress": "MailAddress"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "directmail/receivers",
  "fqn": "pulumi_alicloud.directmail",
  "classes": {
   "alicloud:directmail/receivers:Receivers": "Receivers"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "directmail/tag",
  "fqn": "pulumi_alicloud.directmail",
  "classes": {
   "alicloud:directmail/tag:Tag": "Tag"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dms/enterpriseAuthorityTemplate",
  "fqn": "pulumi_alicloud.dms",
  "classes": {
   "alicloud:dms/enterpriseAuthorityTemplate:EnterpriseAuthorityTemplate": "EnterpriseAuthorityTemplate"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dms/enterpriseInstance",
  "fqn": "pulumi_alicloud.dms",
  "classes": {
   "alicloud:dms/enterpriseInstance:EnterpriseInstance": "EnterpriseInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dms/enterpriseLogicDatabase",
  "fqn": "pulumi_alicloud.dms",
  "classes": {
   "alicloud:dms/enterpriseLogicDatabase:EnterpriseLogicDatabase": "EnterpriseLogicDatabase"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dms/enterpriseProxy",
  "fqn": "pulumi_alicloud.dms",
  "classes": {
   "alicloud:dms/enterpriseProxy:EnterpriseProxy": "EnterpriseProxy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dms/enterpriseProxyAccess",
  "fqn": "pulumi_alicloud.dms",
  "classes": {
   "alicloud:dms/enterpriseProxyAccess:EnterpriseProxyAccess": "EnterpriseProxyAccess"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dms/enterpriseUser",
  "fqn": "pulumi_alicloud.dms",
  "classes": {
   "alicloud:dms/enterpriseUser:EnterpriseUser": "EnterpriseUser"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dns/accessStrategy",
  "fqn": "pulumi_alicloud.dns",
  "classes": {
   "alicloud:dns/accessStrategy:AccessStrategy": "AccessStrategy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dns/addressPool",
  "fqn": "pulumi_alicloud.dns",
  "classes": {
   "alicloud:dns/addressPool:AddressPool": "AddressPool"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dns/alidnsDomain",
  "fqn": "pulumi_alicloud.dns",
  "classes": {
   "alicloud:dns/alidnsDomain:AlidnsDomain": "AlidnsDomain"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dns/alidnsDomainAttachment",
  "fqn": "pulumi_alicloud.dns",
  "classes": {
   "alicloud:dns/alidnsDomainAttachment:AlidnsDomainAttachment": "AlidnsDomainAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dns/alidnsInstance",
  "fqn": "pulumi_alicloud.dns",
  "classes": {
   "alicloud:dns/alidnsInstance:AlidnsInstance": "AlidnsInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dns/alidnsRecord",
  "fqn": "pulumi_alicloud.dns",
  "classes": {
   "alicloud:dns/alidnsRecord:AlidnsRecord": "AlidnsRecord"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dns/customLine",
  "fqn": "pulumi_alicloud.dns",
  "classes": {
   "alicloud:dns/customLine:CustomLine": "CustomLine"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dns/ddosBgpInstance",
  "fqn": "pulumi_alicloud.dns",
  "classes": {
   "alicloud:dns/ddosBgpInstance:DdosBgpInstance": "DdosBgpInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dns/ddosCooInstance",
  "fqn": "pulumi_alicloud.dns",
  "classes": {
   "alicloud:dns/ddosCooInstance:DdosCooInstance": "DdosCooInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dns/dnsDomain",
  "fqn": "pulumi_alicloud.dns",
  "classes": {
   "alicloud:dns/dnsDomain:DnsDomain": "DnsDomain"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dns/domain",
  "fqn": "pulumi_alicloud.dns",
  "classes": {
   "alicloud:dns/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dns/domainAttachment",
  "fqn": "pulumi_alicloud.dns",
  "classes": {
   "alicloud:dns/domainAttachment:DomainAttachment": "DomainAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dns/domainGroup",
  "fqn": "pulumi_alicloud.dns",
  "classes": {
   "alicloud:dns/domainGroup:DomainGroup": "DomainGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dns/group",
  "fqn": "pulumi_alicloud.dns",
  "classes": {
   "alicloud:dns/group:Group": "Group"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dns/gtmInstance",
  "fqn": "pulumi_alicloud.dns",
  "classes": {
   "alicloud:dns/gtmInstance:GtmInstance": "GtmInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dns/instance",
  "fqn": "pulumi_alicloud.dns",
  "classes": {
   "alicloud:dns/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dns/monitorConfig",
  "fqn": "pulumi_alicloud.dns",
  "classes": {
   "alicloud:dns/monitorConfig:MonitorConfig": "MonitorConfig"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dns/record",
  "fqn": "pulumi_alicloud.dns",
  "classes": {
   "alicloud:dns/record:Record": "Record"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "drds/instance",
  "fqn": "pulumi_alicloud.drds",
  "classes": {
   "alicloud:drds/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "drds/polardbxInstance",
  "fqn": "pulumi_alicloud.drds",
  "classes": {
   "alicloud:drds/polardbxInstance:PolardbxInstance": "PolardbxInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dts/consumerChannel",
  "fqn": "pulumi_alicloud.dts",
  "classes": {
   "alicloud:dts/consumerChannel:ConsumerChannel": "ConsumerChannel"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dts/instance",
  "fqn": "pulumi_alicloud.dts",
  "classes": {
   "alicloud:dts/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dts/jobMonitorRule",
  "fqn": "pulumi_alicloud.dts",
  "classes": {
   "alicloud:dts/jobMonitorRule:JobMonitorRule": "JobMonitorRule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dts/migrationInstance",
  "fqn": "pulumi_alicloud.dts",
  "classes": {
   "alicloud:dts/migrationInstance:MigrationInstance": "MigrationInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dts/migrationJob",
  "fqn": "pulumi_alicloud.dts",
  "classes": {
   "alicloud:dts/migrationJob:MigrationJob": "MigrationJob"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dts/subscriptionJob",
  "fqn": "pulumi_alicloud.dts",
  "classes": {
   "alicloud:dts/subscriptionJob:SubscriptionJob": "SubscriptionJob"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dts/synchronizationInstance",
  "fqn": "pulumi_alicloud.dts",
  "classes": {
   "alicloud:dts/synchronizationInstance:SynchronizationInstance": "SynchronizationInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "dts/synchronizationJob",
  "fqn": "pulumi_alicloud.dts",
  "classes": {
   "alicloud:dts/synchronizationJob:SynchronizationJob": "SynchronizationJob"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eais/instance",
  "fqn": "pulumi_alicloud.eais",
  "classes": {
   "alicloud:eais/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ebs/dedicatedBlockStorageCluster",
  "fqn": "pulumi_alicloud.ebs",
  "classes": {
   "alicloud:ebs/dedicatedBlockStorageCluster:DedicatedBlockStorageCluster": "DedicatedBlockStorageCluster"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ebs/diskReplicaGroup",
  "fqn": "pulumi_alicloud.ebs",
  "classes": {
   "alicloud:ebs/diskReplicaGroup:DiskReplicaGroup": "DiskReplicaGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ebs/diskReplicaPair",
  "fqn": "pulumi_alicloud.ebs",
  "classes": {
   "alicloud:ebs/diskReplicaPair:DiskReplicaPair": "DiskReplicaPair"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ebs/enterpriseSnapshotPolicy",
  "fqn": "pulumi_alicloud.ebs",
  "classes": {
   "alicloud:ebs/enterpriseSnapshotPolicy:EnterpriseSnapshotPolicy": "EnterpriseSnapshotPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ebs/enterpriseSnapshotPolicyAttachment",
  "fqn": "pulumi_alicloud.ebs",
  "classes": {
   "alicloud:ebs/enterpriseSnapshotPolicyAttachment:EnterpriseSnapshotPolicyAttachment": "EnterpriseSnapshotPolicyAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ebs/replicaGroupDrill",
  "fqn": "pulumi_alicloud.ebs",
  "classes": {
   "alicloud:ebs/replicaGroupDrill:ReplicaGroupDrill": "ReplicaGroupDrill"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ebs/replicaPairDrill",
  "fqn": "pulumi_alicloud.ebs",
  "classes": {
   "alicloud:ebs/replicaPairDrill:ReplicaPairDrill": "ReplicaPairDrill"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ebs/solutionInstance",
  "fqn": "pulumi_alicloud.ebs",
  "classes": {
   "alicloud:ebs/solutionInstance:SolutionInstance": "SolutionInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eci/containerGroup",
  "fqn": "pulumi_alicloud.eci",
  "classes": {
   "alicloud:eci/containerGroup:ContainerGroup": "ContainerGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eci/imageCache",
  "fqn": "pulumi_alicloud.eci",
  "classes": {
   "alicloud:eci/imageCache:ImageCache": "ImageCache"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eci/openApiImageCache",
  "fqn": "pulumi_alicloud.eci",
  "classes": {
   "alicloud:eci/openApiImageCache:OpenApiImageCache": "OpenApiImageCache"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eci/virtualNode",
  "fqn": "pulumi_alicloud.eci",
  "classes": {
   "alicloud:eci/virtualNode:VirtualNode": "VirtualNode"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecp/instance",
  "fqn": "pulumi_alicloud.ecp",
  "classes": {
   "alicloud:ecp/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecp/keyPair",
  "fqn": "pulumi_alicloud.ecp",
  "classes": {
   "alicloud:ecp/keyPair:KeyPair": "KeyPair"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/activation",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/activation:Activation": "Activation"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/autoProvisioningGroup",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/autoProvisioningGroup:AutoProvisioningGroup": "AutoProvisioningGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/autoSnapshotPolicy",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/autoSnapshotPolicy:AutoSnapshotPolicy": "AutoSnapshotPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/capacityReservation",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/capacityReservation:CapacityReservation": "CapacityReservation"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/command",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/command:Command": "Command"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/copyImage",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/copyImage:CopyImage": "CopyImage"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/dedicatedHost",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/dedicatedHost:DedicatedHost": "DedicatedHost"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/disk",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/disk:Disk": "Disk"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/diskAttachment",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/diskAttachment:DiskAttachment": "DiskAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/ecsAutoSnapshotPolicyAttachment",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/ecsAutoSnapshotPolicyAttachment:EcsAutoSnapshotPolicyAttachment": "EcsAutoSnapshotPolicyAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/ecsDedicatedHostCluster",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/ecsDedicatedHostCluster:EcsDedicatedHostCluster": "EcsDedicatedHostCluster"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/ecsDeploymentSet",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/ecsDeploymentSet:EcsDeploymentSet": "EcsDeploymentSet"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/ecsDisk",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/ecsDisk:EcsDisk": "EcsDisk"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/ecsDiskAttachment",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/ecsDiskAttachment:EcsDiskAttachment": "EcsDiskAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/ecsImageComponent",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/ecsImageComponent:EcsImageComponent": "EcsImageComponent"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/ecsImagePipeline",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/ecsImagePipeline:EcsImagePipeline": "EcsImagePipeline"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/ecsInstanceSet",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/ecsInstanceSet:EcsInstanceSet": "EcsInstanceSet"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/ecsInvocation",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/ecsInvocation:EcsInvocation": "EcsInvocation"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/ecsKeyPair",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/ecsKeyPair:EcsKeyPair": "EcsKeyPair"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/ecsKeyPairAttachment",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/ecsKeyPairAttachment:EcsKeyPairAttachment": "EcsKeyPairAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/ecsLaunchTemplate",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/ecsLaunchTemplate:EcsLaunchTemplate": "EcsLaunchTemplate"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/ecsNetworkInterface",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/ecsNetworkInterface:EcsNetworkInterface": "EcsNetworkInterface"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/ecsNetworkInterfaceAttachment",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/ecsNetworkInterfaceAttachment:EcsNetworkInterfaceAttachment": "EcsNetworkInterfaceAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/ecsNetworkInterfacePermission",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/ecsNetworkInterfacePermission:EcsNetworkInterfacePermission": "EcsNetworkInterfacePermission"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/ecsPrefixList",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/ecsPrefixList:EcsPrefixList": "EcsPrefixList"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/ecsSessionManagerStatus",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/ecsSessionManagerStatus:EcsSessionManagerStatus": "EcsSessionManagerStatus"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/ecsSnapshot",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/ecsSnapshot:EcsSnapshot": "EcsSnapshot"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/ecsSnapshotGroup",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/ecsSnapshotGroup:EcsSnapshotGroup": "EcsSnapshotGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/eip",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/eip:Eip": "Eip"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/eipAddress",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/eipAddress:EipAddress": "EipAddress"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/eipAssociation",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/eipAssociation:EipAssociation": "EipAssociation"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/eipSegmentAddress",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/eipSegmentAddress:EipSegmentAddress": "EipSegmentAddress"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/elasticityAssurance",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/elasticityAssurance:ElasticityAssurance": "ElasticityAssurance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/hpcCluster",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/hpcCluster:HpcCluster": "HpcCluster"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/image",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/image:Image": "Image"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/imageCopy",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/imageCopy:ImageCopy": "ImageCopy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/imageExport",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/imageExport:ImageExport": "ImageExport"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/imageImport",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/imageImport:ImageImport": "ImageImport"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/imageSharePermission",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/imageSharePermission:ImageSharePermission": "ImageSharePermission"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/instance",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/keyPair",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/keyPair:KeyPair": "KeyPair"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/keyPairAttachment",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/keyPairAttachment:KeyPairAttachment": "KeyPairAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/launchTemplate",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/launchTemplate:LaunchTemplate": "LaunchTemplate"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/reservedInstance",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/reservedInstance:ReservedInstance": "ReservedInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/securityGroup",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/securityGroup:SecurityGroup": "SecurityGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/securityGroupRule",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/securityGroupRule:SecurityGroupRule": "SecurityGroupRule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/snapshot",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/snapshotPolicy",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/snapshotPolicy:SnapshotPolicy": "SnapshotPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ecs/storageCapacityUnit",
  "fqn": "pulumi_alicloud.ecs",
  "classes": {
   "alicloud:ecs/storageCapacityUnit:StorageCapacityUnit": "StorageCapacityUnit"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "edas/application",
  "fqn": "pulumi_alicloud.edas",
  "classes": {
   "alicloud:edas/application:Application": "Application"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "edas/applicationDeployment",
  "fqn": "pulumi_alicloud.edas",
  "classes": {
   "alicloud:edas/applicationDeployment:ApplicationDeployment": "ApplicationDeployment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "edas/applicationScale",
  "fqn": "pulumi_alicloud.edas",
  "classes": {
   "alicloud:edas/applicationScale:ApplicationScale": "ApplicationScale"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "edas/cluster",
  "fqn": "pulumi_alicloud.edas",
  "classes": {
   "alicloud:edas/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "edas/deployGroup",
  "fqn": "pulumi_alicloud.edas",
  "classes": {
   "alicloud:edas/deployGroup:DeployGroup": "DeployGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "edas/instanceClusterAttachment",
  "fqn": "pulumi_alicloud.edas",
  "classes": {
   "alicloud:edas/instanceClusterAttachment:InstanceClusterAttachment": "InstanceClusterAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "edas/k8sApplication",
  "fqn": "pulumi_alicloud.edas",
  "classes": {
   "alicloud:edas/k8sApplication:K8sApplication": "K8sApplication"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "edas/k8sCluster",
  "fqn": "pulumi_alicloud.edas",
  "classes": {
   "alicloud:edas/k8sCluster:K8sCluster": "K8sCluster"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "edas/k8sSlbAttachment",
  "fqn": "pulumi_alicloud.edas",
  "classes": {
   "alicloud:edas/k8sSlbAttachment:K8sSlbAttachment": "K8sSlbAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "edas/namespace",
  "fqn": "pulumi_alicloud.edas",
  "classes": {
   "alicloud:edas/namespace:Namespace": "Namespace"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "edas/slbAttachment",
  "fqn": "pulumi_alicloud.edas",
  "classes": {
   "alicloud:edas/slbAttachment:SlbAttachment": "SlbAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eds/adConnectorDirectory",
  "fqn": "pulumi_alicloud.eds",
  "classes": {
   "alicloud:eds/adConnectorDirectory:AdConnectorDirectory": "AdConnectorDirectory"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eds/adConnectorOfficeSite",
  "fqn": "pulumi_alicloud.eds",
  "classes": {
   "alicloud:eds/adConnectorOfficeSite:AdConnectorOfficeSite": "AdConnectorOfficeSite"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eds/bundle",
  "fqn": "pulumi_alicloud.eds",
  "classes": {
   "alicloud:eds/bundle:Bundle": "Bundle"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eds/command",
  "fqn": "pulumi_alicloud.eds",
  "classes": {
   "alicloud:eds/command:Command": "Command"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eds/customProperty",
  "fqn": "pulumi_alicloud.eds",
  "classes": {
   "alicloud:eds/customProperty:CustomProperty": "CustomProperty"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eds/desktop",
  "fqn": "pulumi_alicloud.eds",
  "classes": {
   "alicloud:eds/desktop:Desktop": "Desktop"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eds/ecdPolicyGroup",
  "fqn": "pulumi_alicloud.eds",
  "classes": {
   "alicloud:eds/ecdPolicyGroup:EcdPolicyGroup": "EcdPolicyGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eds/image",
  "fqn": "pulumi_alicloud.eds",
  "classes": {
   "alicloud:eds/image:Image": "Image"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eds/nasFileSystem",
  "fqn": "pulumi_alicloud.eds",
  "classes": {
   "alicloud:eds/nasFileSystem:NasFileSystem": "NasFileSystem"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eds/networkPackage",
  "fqn": "pulumi_alicloud.eds",
  "classes": {
   "alicloud:eds/networkPackage:NetworkPackage": "NetworkPackage"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eds/ramDirectory",
  "fqn": "pulumi_alicloud.eds",
  "classes": {
   "alicloud:eds/ramDirectory:RamDirectory": "RamDirectory"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eds/simpleOfficeSite",
  "fqn": "pulumi_alicloud.eds",
  "classes": {
   "alicloud:eds/simpleOfficeSite:SimpleOfficeSite": "SimpleOfficeSite"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eds/snapshot",
  "fqn": "pulumi_alicloud.eds",
  "classes": {
   "alicloud:eds/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eds/user",
  "fqn": "pulumi_alicloud.eds",
  "classes": {
   "alicloud:eds/user:User": "User"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eflo/subnet",
  "fqn": "pulumi_alicloud.eflo",
  "classes": {
   "alicloud:eflo/subnet:Subnet": "Subnet"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eflo/vpd",
  "fqn": "pulumi_alicloud.eflo",
  "classes": {
   "alicloud:eflo/vpd:Vpd": "Vpd"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ehpc/cluster",
  "fqn": "pulumi_alicloud.ehpc",
  "classes": {
   "alicloud:ehpc/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ehpc/jobTemplate",
  "fqn": "pulumi_alicloud.ehpc",
  "classes": {
   "alicloud:ehpc/jobTemplate:JobTemplate": "JobTemplate"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eipanycast/anycastEipAddress",
  "fqn": "pulumi_alicloud.eipanycast",
  "classes": {
   "alicloud:eipanycast/anycastEipAddress:AnycastEipAddress": "AnycastEipAddress"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eipanycast/anycastEipAddressAttachment",
  "fqn": "pulumi_alicloud.eipanycast",
  "classes": {
   "alicloud:eipanycast/anycastEipAddressAttachment:AnycastEipAddressAttachment": "AnycastEipAddressAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "elasticsearch/instance",
  "fqn": "pulumi_alicloud.elasticsearch",
  "classes": {
   "alicloud:elasticsearch/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "emr/cluster",
  "fqn": "pulumi_alicloud.emr",
  "classes": {
   "alicloud:emr/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "emrv2/cluster",
  "fqn": "pulumi_alicloud.emrv2",
  "classes": {
   "alicloud:emrv2/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ens/disk",
  "fqn": "pulumi_alicloud.ens",
  "classes": {
   "alicloud:ens/disk:Disk": "Disk"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ens/diskInstanceAttachment",
  "fqn": "pulumi_alicloud.ens",
  "classes": {
   "alicloud:ens/diskInstanceAttachment:DiskInstanceAttachment": "DiskInstanceAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ens/eip",
  "fqn": "pulumi_alicloud.ens",
  "classes": {
   "alicloud:ens/eip:Eip": "Eip"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ens/eipInstanceAttachment",
  "fqn": "pulumi_alicloud.ens",
  "classes": {
   "alicloud:ens/eipInstanceAttachment:EipInstanceAttachment": "EipInstanceAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ens/image",
  "fqn": "pulumi_alicloud.ens",
  "classes": {
   "alicloud:ens/image:Image": "Image"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ens/instance",
  "fqn": "pulumi_alicloud.ens",
  "classes": {
   "alicloud:ens/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ens/instanceSecurityGroupAttachment",
  "fqn": "pulumi_alicloud.ens",
  "classes": {
   "alicloud:ens/instanceSecurityGroupAttachment:InstanceSecurityGroupAttachment": "InstanceSecurityGroupAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ens/keyPair",
  "fqn": "pulumi_alicloud.ens",
  "classes": {
   "alicloud:ens/keyPair:KeyPair": "KeyPair"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ens/loadBalancer",
  "fqn": "pulumi_alicloud.ens",
  "classes": {
   "alicloud:ens/loadBalancer:LoadBalancer": "LoadBalancer"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ens/natGateway",
  "fqn": "pulumi_alicloud.ens",
  "classes": {
   "alicloud:ens/natGateway:NatGateway": "NatGateway"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ens/network",
  "fqn": "pulumi_alicloud.ens",
  "classes": {
   "alicloud:ens/network:Network": "Network"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ens/securityGroup",
  "fqn": "pulumi_alicloud.ens",
  "classes": {
   "alicloud:ens/securityGroup:SecurityGroup": "SecurityGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ens/snapshot",
  "fqn": "pulumi_alicloud.ens",
  "classes": {
   "alicloud:ens/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ens/vswitch",
  "fqn": "pulumi_alicloud.ens",
  "classes": {
   "alicloud:ens/vswitch:Vswitch": "Vswitch"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "esa/ratePlanInstance",
  "fqn": "pulumi_alicloud.esa",
  "classes": {
   "alicloud:esa/ratePlanInstance:RatePlanInstance": "RatePlanInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "esa/site",
  "fqn": "pulumi_alicloud.esa",
  "classes": {
   "alicloud:esa/site:Site": "Site"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ess/alarm",
  "fqn": "pulumi_alicloud.ess",
  "classes": {
   "alicloud:ess/alarm:Alarm": "Alarm"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ess/albServerGroupAttachment",
  "fqn": "pulumi_alicloud.ess",
  "classes": {
   "alicloud:ess/albServerGroupAttachment:AlbServerGroupAttachment": "AlbServerGroupAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ess/attachment",
  "fqn": "pulumi_alicloud.ess",
  "classes": {
   "alicloud:ess/attachment:Attachment": "Attachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ess/eciScalingConfiguration",
  "fqn": "pulumi_alicloud.ess",
  "classes": {
   "alicloud:ess/eciScalingConfiguration:EciScalingConfiguration": "EciScalingConfiguration"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ess/lifecycleHook",
  "fqn": "pulumi_alicloud.ess",
  "classes": {
   "alicloud:ess/lifecycleHook:LifecycleHook": "LifecycleHook"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ess/notification",
  "fqn": "pulumi_alicloud.ess",
  "classes": {
   "alicloud:ess/notification:Notification": "Notification"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ess/scalingConfiguration",
  "fqn": "pulumi_alicloud.ess",
  "classes": {
   "alicloud:ess/scalingConfiguration:ScalingConfiguration": "ScalingConfiguration"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ess/scalingGroup",
  "fqn": "pulumi_alicloud.ess",
  "classes": {
   "alicloud:ess/scalingGroup:ScalingGroup": "ScalingGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ess/scalingGroupVServerGroups",
  "fqn": "pulumi_alicloud.ess",
  "classes": {
   "alicloud:ess/scalingGroupVServerGroups:ScalingGroupVServerGroups": "ScalingGroupVServerGroups"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ess/scalingRule",
  "fqn": "pulumi_alicloud.ess",
  "classes": {
   "alicloud:ess/scalingRule:ScalingRule": "ScalingRule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ess/schedule",
  "fqn": "pulumi_alicloud.ess",
  "classes": {
   "alicloud:ess/schedule:Schedule": "Schedule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ess/scheduledTask",
  "fqn": "pulumi_alicloud.ess",
  "classes": {
   "alicloud:ess/scheduledTask:ScheduledTask": "ScheduledTask"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ess/serverGroupAttachment",
  "fqn": "pulumi_alicloud.ess",
  "classes": {
   "alicloud:ess/serverGroupAttachment:ServerGroupAttachment": "ServerGroupAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ess/suspendProcess",
  "fqn": "pulumi_alicloud.ess",
  "classes": {
   "alicloud:ess/suspendProcess:SuspendProcess": "SuspendProcess"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eventbridge/apiDestination",
  "fqn": "pulumi_alicloud.eventbridge",
  "classes": {
   "alicloud:eventbridge/apiDestination:ApiDestination": "ApiDestination"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eventbridge/connection",
  "fqn": "pulumi_alicloud.eventbridge",
  "classes": {
   "alicloud:eventbridge/connection:Connection": "Connection"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eventbridge/eventBus",
  "fqn": "pulumi_alicloud.eventbridge",
  "classes": {
   "alicloud:eventbridge/eventBus:EventBus": "EventBus"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eventbridge/eventSource",
  "fqn": "pulumi_alicloud.eventbridge",
  "classes": {
   "alicloud:eventbridge/eventSource:EventSource": "EventSource"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eventbridge/rule",
  "fqn": "pulumi_alicloud.eventbridge",
  "classes": {
   "alicloud:eventbridge/rule:Rule": "Rule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eventbridge/serviceLinkedRole",
  "fqn": "pulumi_alicloud.eventbridge",
  "classes": {
   "alicloud:eventbridge/serviceLinkedRole:ServiceLinkedRole": "ServiceLinkedRole"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "eventbridge/slr",
  "fqn": "pulumi_alicloud.eventbridge",
  "classes": {
   "alicloud:eventbridge/slr:Slr": "Slr"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "expressconnect/ecFailoverTestJob",
  "fqn": "pulumi_alicloud.expressconnect",
  "classes": {
   "alicloud:expressconnect/ecFailoverTestJob:EcFailoverTestJob": "EcFailoverTestJob"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "expressconnect/grantRuleToCen",
  "fqn": "pulumi_alicloud.expressconnect",
  "classes": {
   "alicloud:expressconnect/grantRuleToCen:GrantRuleToCen": "GrantRuleToCen"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "expressconnect/physicalConnection",
  "fqn": "pulumi_alicloud.expressconnect",
  "classes": {
   "alicloud:expressconnect/physicalConnection:PhysicalConnection": "PhysicalConnection"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "expressconnect/routerExpressConnectRouter",
  "fqn": "pulumi_alicloud.expressconnect",
  "classes": {
   "alicloud:expressconnect/routerExpressConnectRouter:RouterExpressConnectRouter": "RouterExpressConnectRouter"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "expressconnect/routerInterface",
  "fqn": "pulumi_alicloud.expressconnect",
  "classes": {
   "alicloud:expressconnect/routerInterface:RouterInterface": "RouterInterface"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "expressconnect/routerTrAssociation",
  "fqn": "pulumi_alicloud.expressconnect",
  "classes": {
   "alicloud:expressconnect/routerTrAssociation:RouterTrAssociation": "RouterTrAssociation"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "expressconnect/routerVbrChildInstance",
  "fqn": "pulumi_alicloud.expressconnect",
  "classes": {
   "alicloud:expressconnect/routerVbrChildInstance:RouterVbrChildInstance": "RouterVbrChildInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "expressconnect/routerVpcAssociation",
  "fqn": "pulumi_alicloud.expressconnect",
  "classes": {
   "alicloud:expressconnect/routerVpcAssociation:RouterVpcAssociation": "RouterVpcAssociation"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "expressconnect/trafficQos",
  "fqn": "pulumi_alicloud.expressconnect",
  "classes": {
   "alicloud:expressconnect/trafficQos:TrafficQos": "TrafficQos"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "expressconnect/trafficQosAssociation",
  "fqn": "pulumi_alicloud.expressconnect",
  "classes": {
   "alicloud:expressconnect/trafficQosAssociation:TrafficQosAssociation": "TrafficQosAssociation"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "expressconnect/trafficQosQueue",
  "fqn": "pulumi_alicloud.expressconnect",
  "classes": {
   "alicloud:expressconnect/trafficQosQueue:TrafficQosQueue": "TrafficQosQueue"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "expressconnect/trafficQosRule",
  "fqn": "pulumi_alicloud.expressconnect",
  "classes": {
   "alicloud:expressconnect/trafficQosRule:TrafficQosRule": "TrafficQosRule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "expressconnect/vbrPconnAssociation",
  "fqn": "pulumi_alicloud.expressconnect",
  "classes": {
   "alicloud:expressconnect/vbrPconnAssociation:VbrPconnAssociation": "VbrPconnAssociation"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "expressconnect/virtualBorderRouter",
  "fqn": "pulumi_alicloud.expressconnect",
  "classes": {
   "alicloud:expressconnect/virtualBorderRouter:VirtualBorderRouter": "VirtualBorderRouter"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "expressconnect/virtualPhysicalConnection",
  "fqn": "pulumi_alicloud.expressconnect",
  "classes": {
   "alicloud:expressconnect/virtualPhysicalConnection:VirtualPhysicalConnection": "VirtualPhysicalConnection"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "fc/alias",
  "fqn": "pulumi_alicloud.fc",
  "classes": {
   "alicloud:fc/alias:Alias": "Alias"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "fc/customDomain",
  "fqn": "pulumi_alicloud.fc",
  "classes": {
   "alicloud:fc/customDomain:CustomDomain": "CustomDomain"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "fc/function",
  "fqn": "pulumi_alicloud.fc",
  "classes": {
   "alicloud:fc/function:Function": "Function"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "fc/functionAsyncInvokeConfig",
  "fqn": "pulumi_alicloud.fc",
  "classes": {
   "alicloud:fc/functionAsyncInvokeConfig:FunctionAsyncInvokeConfig": "FunctionAsyncInvokeConfig"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "fc/layerVersion",
  "fqn": "pulumi_alicloud.fc",
  "classes": {
   "alicloud:fc/layerVersion:LayerVersion": "LayerVersion"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "fc/service",
  "fqn": "pulumi_alicloud.fc",
  "classes": {
   "alicloud:fc/service:Service": "Service"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "fc/trigger",
  "fqn": "pulumi_alicloud.fc",
  "classes": {
   "alicloud:fc/trigger:Trigger": "Trigger"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "fc/v2Function",
  "fqn": "pulumi_alicloud.fc",
  "classes": {
   "alicloud:fc/v2Function:V2Function": "V2Function"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "fc/v3Alias",
  "fqn": "pulumi_alicloud.fc",
  "classes": {
   "alicloud:fc/v3Alias:V3Alias": "V3Alias"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "fc/v3AsyncInvokeConfig",
  "fqn": "pulumi_alicloud.fc",
  "classes": {
   "alicloud:fc/v3AsyncInvokeConfig:V3AsyncInvokeConfig": "V3AsyncInvokeConfig"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "fc/v3ConcurrencyConfig",
  "fqn": "pulumi_alicloud.fc",
  "classes": {
   "alicloud:fc/v3ConcurrencyConfig:V3ConcurrencyConfig": "V3ConcurrencyConfig"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "fc/v3CustomDomain",
  "fqn": "pulumi_alicloud.fc",
  "classes": {
   "alicloud:fc/v3CustomDomain:V3CustomDomain": "V3CustomDomain"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "fc/v3Function",
  "fqn": "pulumi_alicloud.fc",
  "classes": {
   "alicloud:fc/v3Function:V3Function": "V3Function"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "fc/v3FunctionVersion",
  "fqn": "pulumi_alicloud.fc",
  "classes": {
   "alicloud:fc/v3FunctionVersion:V3FunctionVersion": "V3FunctionVersion"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "fc/v3LayerVersion",
  "fqn": "pulumi_alicloud.fc",
  "classes": {
   "alicloud:fc/v3LayerVersion:V3LayerVersion": "V3LayerVersion"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "fc/v3ProvisionConfig",
  "fqn": "pulumi_alicloud.fc",
  "classes": {
   "alicloud:fc/v3ProvisionConfig:V3ProvisionConfig": "V3ProvisionConfig"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "fc/v3Trigger",
  "fqn": "pulumi_alicloud.fc",
  "classes": {
   "alicloud:fc/v3Trigger:V3Trigger": "V3Trigger"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "fc/v3VpcBinding",
  "fqn": "pulumi_alicloud.fc",
  "classes": {
   "alicloud:fc/v3VpcBinding:V3VpcBinding": "V3VpcBinding"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "fnf/execution",
  "fqn": "pulumi_alicloud.fnf",
  "classes": {
   "alicloud:fnf/execution:Execution": "Execution"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "fnf/flow",
  "fqn": "pulumi_alicloud.fnf",
  "classes": {
   "alicloud:fnf/flow:Flow": "Flow"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "fnf/schedule",
  "fqn": "pulumi_alicloud.fnf",
  "classes": {
   "alicloud:fnf/schedule:Schedule": "Schedule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ga/accelerator",
  "fqn": "pulumi_alicloud.ga",
  "classes": {
   "alicloud:ga/accelerator:Accelerator": "Accelerator"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ga/acceleratorSpareIpAttachment",
  "fqn": "pulumi_alicloud.ga",
  "classes": {
   "alicloud:ga/acceleratorSpareIpAttachment:AcceleratorSpareIpAttachment": "AcceleratorSpareIpAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ga/accessLog",
  "fqn": "pulumi_alicloud.ga",
  "classes": {
   "alicloud:ga/accessLog:AccessLog": "AccessLog"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ga/acl",
  "fqn": "pulumi_alicloud.ga",
  "classes": {
   "alicloud:ga/acl:Acl": "Acl"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ga/aclAttachment",
  "fqn": "pulumi_alicloud.ga",
  "classes": {
   "alicloud:ga/aclAttachment:AclAttachment": "AclAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ga/aclEntryAttachment",
  "fqn": "pulumi_alicloud.ga",
  "classes": {
   "alicloud:ga/aclEntryAttachment:AclEntryAttachment": "AclEntryAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ga/additionalCertificate",
  "fqn": "pulumi_alicloud.ga",
  "classes": {
   "alicloud:ga/additionalCertificate:AdditionalCertificate": "AdditionalCertificate"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ga/bandwidthPackage",
  "fqn": "pulumi_alicloud.ga",
  "classes": {
   "alicloud:ga/bandwidthPackage:BandwidthPackage": "BandwidthPackage"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ga/bandwidthPackageAttachment",
  "fqn": "pulumi_alicloud.ga",
  "classes": {
   "alicloud:ga/bandwidthPackageAttachment:BandwidthPackageAttachment": "BandwidthPackageAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ga/basicAccelerateIp",
  "fqn": "pulumi_alicloud.ga",
  "classes": {
   "alicloud:ga/basicAccelerateIp:BasicAccelerateIp": "BasicAccelerateIp"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ga/basicAccelerateIpEndpointRelation",
  "fqn": "pulumi_alicloud.ga",
  "classes": {
   "alicloud:ga/basicAccelerateIpEndpointRelation:BasicAccelerateIpEndpointRelation": "BasicAccelerateIpEndpointRelation"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ga/basicAccelerator",
  "fqn": "pulumi_alicloud.ga",
  "classes": {
   "alicloud:ga/basicAccelerator:BasicAccelerator": "BasicAccelerator"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ga/basicEndpoint",
  "fqn": "pulumi_alicloud.ga",
  "classes": {
   "alicloud:ga/basicEndpoint:BasicEndpoint": "BasicEndpoint"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ga/basicEndpointGroup",
  "fqn": "pulumi_alicloud.ga",
  "classes": {
   "alicloud:ga/basicEndpointGroup:BasicEndpointGroup": "BasicEndpointGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ga/basicIpSet",
  "fqn": "pulumi_alicloud.ga",
  "classes": {
   "alicloud:ga/basicIpSet:BasicIpSet": "BasicIpSet"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ga/customRoutingEndpoint",
  "fqn": "pulumi_alicloud.ga",
  "classes": {
   "alicloud:ga/customRoutingEndpoint:CustomRoutingEndpoint": "CustomRoutingEndpoint"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ga/customRoutingEndpointGroup",
  "fqn": "pulumi_alicloud.ga",
  "classes": {
   "alicloud:ga/customRoutingEndpointGroup:CustomRoutingEndpointGroup": "CustomRoutingEndpointGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ga/customRoutingEndpointGroupDestination",
  "fqn": "pulumi_alicloud.ga",
  "classes": {
   "alicloud:ga/customRoutingEndpointGroupDestination:CustomRoutingEndpointGroupDestination": "CustomRoutingEndpointGroupDestination"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ga/customRoutingEndpointTrafficPolicy",
  "fqn": "pulumi_alicloud.ga",
  "classes": {
   "alicloud:ga/customRoutingEndpointTrafficPolicy:CustomRoutingEndpointTrafficPolicy": "CustomRoutingEndpointTrafficPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ga/domain",
  "fqn": "pulumi_alicloud.ga",
  "classes": {
   "alicloud:ga/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ga/endpointGroup",
  "fqn": "pulumi_alicloud.ga",
  "classes": {
   "alicloud:ga/endpointGroup:EndpointGroup": "EndpointGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ga/forwardingRule",
  "fqn": "pulumi_alicloud.ga",
  "classes": {
   "alicloud:ga/forwardingRule:ForwardingRule": "ForwardingRule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ga/ipSet",
  "fqn": "pulumi_alicloud.ga",
  "classes": {
   "alicloud:ga/ipSet:IpSet": "IpSet"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ga/listener",
  "fqn": "pulumi_alicloud.ga",
  "classes": {
   "alicloud:ga/listener:Listener": "Listener"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "governance/account",
  "fqn": "pulumi_alicloud.governance",
  "classes": {
   "alicloud:governance/account:Account": "Account"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "governance/baseline",
  "fqn": "pulumi_alicloud.governance",
  "classes": {
   "alicloud:governance/baseline:Baseline": "Baseline"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "gpdb/account",
  "fqn": "pulumi_alicloud.gpdb",
  "classes": {
   "alicloud:gpdb/account:Account": "Account"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "gpdb/backupPolicy",
  "fqn": "pulumi_alicloud.gpdb",
  "classes": {
   "alicloud:gpdb/backupPolicy:BackupPolicy": "BackupPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "gpdb/connection",
  "fqn": "pulumi_alicloud.gpdb",
  "classes": {
   "alicloud:gpdb/connection:Connection": "Connection"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "gpdb/database",
  "fqn": "pulumi_alicloud.gpdb",
  "classes": {
   "alicloud:gpdb/database:Database": "Database"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "gpdb/dbInstanceIpArray",
  "fqn": "pulumi_alicloud.gpdb",
  "classes": {
   "alicloud:gpdb/dbInstanceIpArray:DbInstanceIpArray": "DbInstanceIpArray"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "gpdb/dbInstancePlan",
  "fqn": "pulumi_alicloud.gpdb",
  "classes": {
   "alicloud:gpdb/dbInstancePlan:DbInstancePlan": "DbInstancePlan"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "gpdb/dbResourceGroup",
  "fqn": "pulumi_alicloud.gpdb",
  "classes": {
   "alicloud:gpdb/dbResourceGroup:DbResourceGroup": "DbResourceGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "gpdb/elasticInstance",
  "fqn": "pulumi_alicloud.gpdb",
  "classes": {
   "alicloud:gpdb/elasticInstance:ElasticInstance": "ElasticInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "gpdb/externalDataService",
  "fqn": "pulumi_alicloud.gpdb",
  "classes": {
   "alicloud:gpdb/externalDataService:ExternalDataService": "ExternalDataService"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "gpdb/hadoopDataSource",
  "fqn": "pulumi_alicloud.gpdb",
  "classes": {
   "alicloud:gpdb/hadoopDataSource:HadoopDataSource": "HadoopDataSource"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "gpdb/instance",
  "fqn": "pulumi_alicloud.gpdb",
  "classes": {
   "alicloud:gpdb/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "gpdb/jdbcDataSource",
  "fqn": "pulumi_alicloud.gpdb",
  "classes": {
   "alicloud:gpdb/jdbcDataSource:JdbcDataSource": "JdbcDataSource"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "gpdb/remoteAdbDataSource",
  "fqn": "pulumi_alicloud.gpdb",
  "classes": {
   "alicloud:gpdb/remoteAdbDataSource:RemoteAdbDataSource": "RemoteAdbDataSource"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "gpdb/streamingDataService",
  "fqn": "pulumi_alicloud.gpdb",
  "classes": {
   "alicloud:gpdb/streamingDataService:StreamingDataService": "StreamingDataService"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "gpdb/streamingDataSource",
  "fqn": "pulumi_alicloud.gpdb",
  "classes": {
   "alicloud:gpdb/streamingDataSource:StreamingDataSource": "StreamingDataSource"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "gpdb/streamingJob",
  "fqn": "pulumi_alicloud.gpdb",
  "classes": {
   "alicloud:gpdb/streamingJob:StreamingJob": "StreamingJob"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "graphdatabase/dbInstance",
  "fqn": "pulumi_alicloud.graphdatabase",
  "classes": {
   "alicloud:graphdatabase/dbInstance:DbInstance": "DbInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "gwlb/listener",
  "fqn": "pulumi_alicloud.gwlb",
  "classes": {
   "alicloud:gwlb/listener:Listener": "Listener"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "gwlb/loadBalancer",
  "fqn": "pulumi_alicloud.gwlb",
  "classes": {
   "alicloud:gwlb/loadBalancer:LoadBalancer": "LoadBalancer"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "gwlb/serverGroup",
  "fqn": "pulumi_alicloud.gwlb",
  "classes": {
   "alicloud:gwlb/serverGroup:ServerGroup": "ServerGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "hbase/instance",
  "fqn": "pulumi_alicloud.hbase",
  "classes": {
   "alicloud:hbase/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "hbr/ecsBackupClient",
  "fqn": "pulumi_alicloud.hbr",
  "classes": {
   "alicloud:hbr/ecsBackupClient:EcsBackupClient": "EcsBackupClient"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "hbr/ecsBackupPlan",
  "fqn": "pulumi_alicloud.hbr",
  "classes": {
   "alicloud:hbr/ecsBackupPlan:EcsBackupPlan": "EcsBackupPlan"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "hbr/hanaBackupClient",
  "fqn": "pulumi_alicloud.hbr",
  "classes": {
   "alicloud:hbr/hanaBackupClient:HanaBackupClient": "HanaBackupClient"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "hbr/hanaBackupPlan",
  "fqn": "pulumi_alicloud.hbr",
  "classes": {
   "alicloud:hbr/hanaBackupPlan:HanaBackupPlan": "HanaBackupPlan"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "hbr/hanaInstance",
  "fqn": "pulumi_alicloud.hbr",
  "classes": {
   "alicloud:hbr/hanaInstance:HanaInstance": "HanaInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "hbr/nasBackupPlan",
  "fqn": "pulumi_alicloud.hbr",
  "classes": {
   "alicloud:hbr/nasBackupPlan:NasBackupPlan": "NasBackupPlan"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "hbr/ossBackupPlan",
  "fqn": "pulumi_alicloud.hbr",
  "classes": {
   "alicloud:hbr/ossBackupPlan:OssBackupPlan": "OssBackupPlan"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "hbr/otsBackupPlan",
  "fqn": "pulumi_alicloud.hbr",
  "classes": {
   "alicloud:hbr/otsBackupPlan:OtsBackupPlan": "OtsBackupPlan"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "hbr/policy",
  "fqn": "pulumi_alicloud.hbr",
  "classes": {
   "alicloud:hbr/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "hbr/policyBinding",
  "fqn": "pulumi_alicloud.hbr",
  "classes": {
   "alicloud:hbr/policyBinding:PolicyBinding": "PolicyBinding"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "hbr/replicationVault",
  "fqn": "pulumi_alicloud.hbr",
  "classes": {
   "alicloud:hbr/replicationVault:ReplicationVault": "ReplicationVault"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "hbr/restoreJob",
  "fqn": "pulumi_alicloud.hbr",
  "classes": {
   "alicloud:hbr/restoreJob:RestoreJob": "RestoreJob"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "hbr/serverBackupPlan",
  "fqn": "pulumi_alicloud.hbr",
  "classes": {
   "alicloud:hbr/serverBackupPlan:ServerBackupPlan": "ServerBackupPlan"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "hbr/vault",
  "fqn": "pulumi_alicloud.hbr",
  "classes": {
   "alicloud:hbr/vault:Vault": "Vault"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "hologram/instance",
  "fqn": "pulumi_alicloud.hologram",
  "classes": {
   "alicloud:hologram/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "imm/project",
  "fqn": "pulumi_alicloud.imm",
  "classes": {
   "alicloud:imm/project:Project": "Project"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "imp/appTemplate",
  "fqn": "pulumi_alicloud.imp",
  "classes": {
   "alicloud:imp/appTemplate:AppTemplate": "AppTemplate"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ims/oidcProvider",
  "fqn": "pulumi_alicloud.ims",
  "classes": {
   "alicloud:ims/oidcProvider:OidcProvider": "OidcProvider"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "index/mscSubContract",
  "fqn": "pulumi_alicloud",
  "classes": {
   "alicloud:index/mscSubContract:MscSubContract": "MscSubContract"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "index/mscSubSubscription",
  "fqn": "pulumi_alicloud",
  "classes": {
   "alicloud:index/mscSubSubscription:MscSubSubscription": "MscSubSubscription"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "index/mscSubWebhook",
  "fqn": "pulumi_alicloud",
  "classes": {
   "alicloud:index/mscSubWebhook:MscSubWebhook": "MscSubWebhook"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "iot/deviceGroup",
  "fqn": "pulumi_alicloud.iot",
  "classes": {
   "alicloud:iot/deviceGroup:DeviceGroup": "DeviceGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "kms/alias",
  "fqn": "pulumi_alicloud.kms",
  "classes": {
   "alicloud:kms/alias:Alias": "Alias"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "kms/applicationAccessPoint",
  "fqn": "pulumi_alicloud.kms",
  "classes": {
   "alicloud:kms/applicationAccessPoint:ApplicationAccessPoint": "ApplicationAccessPoint"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "kms/ciphertext",
  "fqn": "pulumi_alicloud.kms",
  "classes": {
   "alicloud:kms/ciphertext:Ciphertext": "Ciphertext"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "kms/clientKey",
  "fqn": "pulumi_alicloud.kms",
  "classes": {
   "alicloud:kms/clientKey:ClientKey": "ClientKey"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "kms/instance",
  "fqn": "pulumi_alicloud.kms",
  "classes": {
   "alicloud:kms/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "kms/key",
  "fqn": "pulumi_alicloud.kms",
  "classes": {
   "alicloud:kms/key:Key": "Key"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "kms/keyVersion",
  "fqn": "pulumi_alicloud.kms",
  "classes": {
   "alicloud:kms/keyVersion:KeyVersion": "KeyVersion"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "kms/networkRule",
  "fqn": "pulumi_alicloud.kms",
  "classes": {
   "alicloud:kms/networkRule:NetworkRule": "NetworkRule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "kms/policy",
  "fqn": "pulumi_alicloud.kms",
  "classes": {
   "alicloud:kms/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "kms/secret",
  "fqn": "pulumi_alicloud.kms",
  "classes": {
   "alicloud:kms/secret:Secret": "Secret"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "kvstore/account",
  "fqn": "pulumi_alicloud.kvstore",
  "classes": {
   "alicloud:kvstore/account:Account": "Account"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "kvstore/auditLogConfig",
  "fqn": "pulumi_alicloud.kvstore",
  "classes": {
   "alicloud:kvstore/auditLogConfig:AuditLogConfig": "AuditLogConfig"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "kvstore/backupPolicy",
  "fqn": "pulumi_alicloud.kvstore",
  "classes": {
   "alicloud:kvstore/backupPolicy:BackupPolicy": "BackupPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "kvstore/connection",
  "fqn": "pulumi_alicloud.kvstore",
  "classes": {
   "alicloud:kvstore/connection:Connection": "Connection"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "kvstore/instance",
  "fqn": "pulumi_alicloud.kvstore",
  "classes": {
   "alicloud:kvstore/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "lindorm/instance",
  "fqn": "pulumi_alicloud.lindorm",
  "classes": {
   "alicloud:lindorm/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "log/alert",
  "fqn": "pulumi_alicloud.log",
  "classes": {
   "alicloud:log/alert:Alert": "Alert"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "log/alertResource",
  "fqn": "pulumi_alicloud.log",
  "classes": {
   "alicloud:log/alertResource:AlertResource": "AlertResource"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "log/audit",
  "fqn": "pulumi_alicloud.log",
  "classes": {
   "alicloud:log/audit:Audit": "Audit"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "log/dashboard",
  "fqn": "pulumi_alicloud.log",
  "classes": {
   "alicloud:log/dashboard:Dashboard": "Dashboard"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "log/etl",
  "fqn": "pulumi_alicloud.log",
  "classes": {
   "alicloud:log/etl:Etl": "Etl"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "log/ingestion",
  "fqn": "pulumi_alicloud.log",
  "classes": {
   "alicloud:log/ingestion:Ingestion": "Ingestion"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "log/logTailAttachment",
  "fqn": "pulumi_alicloud.log",
  "classes": {
   "alicloud:log/logTailAttachment:LogTailAttachment": "LogTailAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "log/logTailConfig",
  "fqn": "pulumi_alicloud.log",
  "classes": {
   "alicloud:log/logTailConfig:LogTailConfig": "LogTailConfig"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "log/machineGroup",
  "fqn": "pulumi_alicloud.log",
  "classes": {
   "alicloud:log/machineGroup:MachineGroup": "MachineGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "log/ossExport",
  "fqn": "pulumi_alicloud.log",
  "classes": {
   "alicloud:log/ossExport:OssExport": "OssExport"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "log/ossShipper",
  "fqn": "pulumi_alicloud.log",
  "classes": {
   "alicloud:log/ossShipper:OssShipper": "OssShipper"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "log/project",
  "fqn": "pulumi_alicloud.log",
  "classes": {
   "alicloud:log/project:Project": "Project"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "log/resource",
  "fqn": "pulumi_alicloud.log",
  "classes": {
   "alicloud:log/resource:Resource": "Resource"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "log/resourceRecord",
  "fqn": "pulumi_alicloud.log",
  "classes": {
   "alicloud:log/resourceRecord:ResourceRecord": "ResourceRecord"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "log/store",
  "fqn": "pulumi_alicloud.log",
  "classes": {
   "alicloud:log/store:Store": "Store"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "log/storeIndex",
  "fqn": "pulumi_alicloud.log",
  "classes": {
   "alicloud:log/storeIndex:StoreIndex": "StoreIndex"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "marketplace/order",
  "fqn": "pulumi_alicloud.marketplace",
  "classes": {
   "alicloud:marketplace/order:Order": "Order"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "maxcompute/project",
  "fqn": "pulumi_alicloud.maxcompute",
  "classes": {
   "alicloud:maxcompute/project:Project": "Project"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "message/serviceQueue",
  "fqn": "pulumi_alicloud.message",
  "classes": {
   "alicloud:message/serviceQueue:ServiceQueue": "ServiceQueue"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "message/serviceSubscription",
  "fqn": "pulumi_alicloud.message",
  "classes": {
   "alicloud:message/serviceSubscription:ServiceSubscription": "ServiceSubscription"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "message/serviceTopic",
  "fqn": "pulumi_alicloud.message",
  "classes": {
   "alicloud:message/serviceTopic:ServiceTopic": "ServiceTopic"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "mhub/app",
  "fqn": "pulumi_alicloud.mhub",
  "classes": {
   "alicloud:mhub/app:App": "App"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "mhub/product",
  "fqn": "pulumi_alicloud.mhub",
  "classes": {
   "alicloud:mhub/product:Product": "Product"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "mns/queue",
  "fqn": "pulumi_alicloud.mns",
  "classes": {
   "alicloud:mns/queue:Queue": "Queue"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "mns/topic",
  "fqn": "pulumi_alicloud.mns",
  "classes": {
   "alicloud:mns/topic:Topic": "Topic"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "mns/topicSubscription",
  "fqn": "pulumi_alicloud.mns",
  "classes": {
   "alicloud:mns/topicSubscription:TopicSubscription": "TopicSubscription"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "mongodb/account",
  "fqn": "pulumi_alicloud.mongodb",
  "classes": {
   "alicloud:mongodb/account:Account": "Account"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "mongodb/auditPolicy",
  "fqn": "pulumi_alicloud.mongodb",
  "classes": {
   "alicloud:mongodb/auditPolicy:AuditPolicy": "AuditPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "mongodb/instance",
  "fqn": "pulumi_alicloud.mongodb",
  "classes": {
   "alicloud:mongodb/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "mongodb/serverlessInstance",
  "fqn": "pulumi_alicloud.mongodb",
  "classes": {
   "alicloud:mongodb/serverlessInstance:ServerlessInstance": "ServerlessInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "mongodb/shardingInstance",
  "fqn": "pulumi_alicloud.mongodb",
  "classes": {
   "alicloud:mongodb/shardingInstance:ShardingInstance": "ShardingInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "mongodb/shardingNetworkPrivateAddress",
  "fqn": "pulumi_alicloud.mongodb",
  "classes": {
   "alicloud:mongodb/shardingNetworkPrivateAddress:ShardingNetworkPrivateAddress": "ShardingNetworkPrivateAddress"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "mongodb/shardingNetworkPublicAddress",
  "fqn": "pulumi_alicloud.mongodb",
  "classes": {
   "alicloud:mongodb/shardingNetworkPublicAddress:ShardingNetworkPublicAddress": "ShardingNetworkPublicAddress"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "mse/cluster",
  "fqn": "pulumi_alicloud.mse",
  "classes": {
   "alicloud:mse/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "mse/engineNamespace",
  "fqn": "pulumi_alicloud.mse",
  "classes": {
   "alicloud:mse/engineNamespace:EngineNamespace": "EngineNamespace"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "mse/gateway",
  "fqn": "pulumi_alicloud.mse",
  "classes": {
   "alicloud:mse/gateway:Gateway": "Gateway"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "mse/nacosConfig",
  "fqn": "pulumi_alicloud.mse",
  "classes": {
   "alicloud:mse/nacosConfig:NacosConfig": "NacosConfig"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "mse/znode",
  "fqn": "pulumi_alicloud.mse",
  "classes": {
   "alicloud:mse/znode:Znode": "Znode"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "nas/accessGroup",
  "fqn": "pulumi_alicloud.nas",
  "classes": {
   "alicloud:nas/accessGroup:AccessGroup": "AccessGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "nas/accessPoint",
  "fqn": "pulumi_alicloud.nas",
  "classes": {
   "alicloud:nas/accessPoint:AccessPoint": "AccessPoint"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "nas/accessRule",
  "fqn": "pulumi_alicloud.nas",
  "classes": {
   "alicloud:nas/accessRule:AccessRule": "AccessRule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "nas/autoSnapshotPolicy",
  "fqn": "pulumi_alicloud.nas",
  "classes": {
   "alicloud:nas/autoSnapshotPolicy:AutoSnapshotPolicy": "AutoSnapshotPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "nas/dataFlow",
  "fqn": "pulumi_alicloud.nas",
  "classes": {
   "alicloud:nas/dataFlow:DataFlow": "DataFlow"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "nas/fileSystem",
  "fqn": "pulumi_alicloud.nas",
  "classes": {
   "alicloud:nas/fileSystem:FileSystem": "FileSystem"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "nas/fileset",
  "fqn": "pulumi_alicloud.nas",
  "classes": {
   "alicloud:nas/fileset:Fileset": "Fileset"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "nas/lifecyclePolicy",
  "fqn": "pulumi_alicloud.nas",
  "classes": {
   "alicloud:nas/lifecyclePolicy:LifecyclePolicy": "LifecyclePolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "nas/mountTarget",
  "fqn": "pulumi_alicloud.nas",
  "classes": {
   "alicloud:nas/mountTarget:MountTarget": "MountTarget"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "nas/recycleBin",
  "fqn": "pulumi_alicloud.nas",
  "classes": {
   "alicloud:nas/recycleBin:RecycleBin": "RecycleBin"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "nas/smbAclAttachment",
  "fqn": "pulumi_alicloud.nas",
  "classes": {
   "alicloud:nas/smbAclAttachment:SmbAclAttachment": "SmbAclAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "nas/snapshot",
  "fqn": "pulumi_alicloud.nas",
  "classes": {
   "alicloud:nas/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "nlb/listener",
  "fqn": "pulumi_alicloud.nlb",
  "classes": {
   "alicloud:nlb/listener:Listener": "Listener"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "nlb/listenerAdditionalCertificateAttachment",
  "fqn": "pulumi_alicloud.nlb",
  "classes": {
   "alicloud:nlb/listenerAdditionalCertificateAttachment:ListenerAdditionalCertificateAttachment": "ListenerAdditionalCertificateAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "nlb/loadBalancer",
  "fqn": "pulumi_alicloud.nlb",
  "classes": {
   "alicloud:nlb/loadBalancer:LoadBalancer": "LoadBalancer"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "nlb/loadBalancerSecurityGroupAttachment",
  "fqn": "pulumi_alicloud.nlb",
  "classes": {
   "alicloud:nlb/loadBalancerSecurityGroupAttachment:LoadBalancerSecurityGroupAttachment": "LoadBalancerSecurityGroupAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "nlb/loadbalancerCommonBandwidthPackageAttachment",
  "fqn": "pulumi_alicloud.nlb",
  "classes": {
   "alicloud:nlb/loadbalancerCommonBandwidthPackageAttachment:LoadbalancerCommonBandwidthPackageAttachment": "LoadbalancerCommonBandwidthPackageAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "nlb/securityPolicy",
  "fqn": "pulumi_alicloud.nlb",
  "classes": {
   "alicloud:nlb/securityPolicy:SecurityPolicy": "SecurityPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "nlb/serverGroup",
  "fqn": "pulumi_alicloud.nlb",
  "classes": {
   "alicloud:nlb/serverGroup:ServerGroup": "ServerGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "nlb/serverGroupServerAttachment",
  "fqn": "pulumi_alicloud.nlb",
  "classes": {
   "alicloud:nlb/serverGroupServerAttachment:ServerGroupServerAttachment": "ServerGroupServerAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ocean/baseInstance",
  "fqn": "pulumi_alicloud.ocean",
  "classes": {
   "alicloud:ocean/baseInstance:BaseInstance": "BaseInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oos/application",
  "fqn": "pulumi_alicloud.oos",
  "classes": {
   "alicloud:oos/application:Application": "Application"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oos/applicationGroup",
  "fqn": "pulumi_alicloud.oos",
  "classes": {
   "alicloud:oos/applicationGroup:ApplicationGroup": "ApplicationGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oos/defaultPatchBaseline",
  "fqn": "pulumi_alicloud.oos",
  "classes": {
   "alicloud:oos/defaultPatchBaseline:DefaultPatchBaseline": "DefaultPatchBaseline"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oos/execution",
  "fqn": "pulumi_alicloud.oos",
  "classes": {
   "alicloud:oos/execution:Execution": "Execution"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oos/parameter",
  "fqn": "pulumi_alicloud.oos",
  "classes": {
   "alicloud:oos/parameter:Parameter": "Parameter"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oos/patchBaseline",
  "fqn": "pulumi_alicloud.oos",
  "classes": {
   "alicloud:oos/patchBaseline:PatchBaseline": "PatchBaseline"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oos/secretParameter",
  "fqn": "pulumi_alicloud.oos",
  "classes": {
   "alicloud:oos/secretParameter:SecretParameter": "SecretParameter"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oos/serviceSetting",
  "fqn": "pulumi_alicloud.oos",
  "classes": {
   "alicloud:oos/serviceSetting:ServiceSetting": "ServiceSetting"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oos/stateConfiguration",
  "fqn": "pulumi_alicloud.oos",
  "classes": {
   "alicloud:oos/stateConfiguration:StateConfiguration": "StateConfiguration"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oos/template",
  "fqn": "pulumi_alicloud.oos",
  "classes": {
   "alicloud:oos/template:Template": "Template"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "opensearch/appGroup",
  "fqn": "pulumi_alicloud.opensearch",
  "classes": {
   "alicloud:opensearch/appGroup:AppGroup": "AppGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oss/accountPublicAccessBlock",
  "fqn": "pulumi_alicloud.oss",
  "classes": {
   "alicloud:oss/accountPublicAccessBlock:AccountPublicAccessBlock": "AccountPublicAccessBlock"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oss/bucket",
  "fqn": "pulumi_alicloud.oss",
  "classes": {
   "alicloud:oss/bucket:Bucket": "Bucket"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oss/bucketAccessMonitor",
  "fqn": "pulumi_alicloud.oss",
  "classes": {
   "alicloud:oss/bucketAccessMonitor:BucketAccessMonitor": "BucketAccessMonitor"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oss/bucketAcl",
  "fqn": "pulumi_alicloud.oss",
  "classes": {
   "alicloud:oss/bucketAcl:BucketAcl": "BucketAcl"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oss/bucketCname",
  "fqn": "pulumi_alicloud.oss",
  "classes": {
   "alicloud:oss/bucketCname:BucketCname": "BucketCname"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oss/bucketCnameToken",
  "fqn": "pulumi_alicloud.oss",
  "classes": {
   "alicloud:oss/bucketCnameToken:BucketCnameToken": "BucketCnameToken"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oss/bucketCors",
  "fqn": "pulumi_alicloud.oss",
  "classes": {
   "alicloud:oss/bucketCors:BucketCors": "BucketCors"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oss/bucketDataRedundancyTransition",
  "fqn": "pulumi_alicloud.oss",
  "classes": {
   "alicloud:oss/bucketDataRedundancyTransition:BucketDataRedundancyTransition": "BucketDataRedundancyTransition"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oss/bucketHttpsConfig",
  "fqn": "pulumi_alicloud.oss",
  "classes": {
   "alicloud:oss/bucketHttpsConfig:BucketHttpsConfig": "BucketHttpsConfig"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oss/bucketLogging",
  "fqn": "pulumi_alicloud.oss",
  "classes": {
   "alicloud:oss/bucketLogging:BucketLogging": "BucketLogging"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oss/bucketMetaQuery",
  "fqn": "pulumi_alicloud.oss",
  "classes": {
   "alicloud:oss/bucketMetaQuery:BucketMetaQuery": "BucketMetaQuery"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oss/bucketObject",
  "fqn": "pulumi_alicloud.oss",
  "classes": {
   "alicloud:oss/bucketObject:BucketObject": "BucketObject"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oss/bucketPolicy",
  "fqn": "pulumi_alicloud.oss",
  "classes": {
   "alicloud:oss/bucketPolicy:BucketPolicy": "BucketPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oss/bucketPublicAccessBlock",
  "fqn": "pulumi_alicloud.oss",
  "classes": {
   "alicloud:oss/bucketPublicAccessBlock:BucketPublicAccessBlock": "BucketPublicAccessBlock"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oss/bucketReferer",
  "fqn": "pulumi_alicloud.oss",
  "classes": {
   "alicloud:oss/bucketReferer:BucketReferer": "BucketReferer"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oss/bucketReplication",
  "fqn": "pulumi_alicloud.oss",
  "classes": {
   "alicloud:oss/bucketReplication:BucketReplication": "BucketReplication"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oss/bucketRequestPayment",
  "fqn": "pulumi_alicloud.oss",
  "classes": {
   "alicloud:oss/bucketRequestPayment:BucketRequestPayment": "BucketRequestPayment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oss/bucketServerSideEncryption",
  "fqn": "pulumi_alicloud.oss",
  "classes": {
   "alicloud:oss/bucketServerSideEncryption:BucketServerSideEncryption": "BucketServerSideEncryption"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oss/bucketTransferAcceleration",
  "fqn": "pulumi_alicloud.oss",
  "classes": {
   "alicloud:oss/bucketTransferAcceleration:BucketTransferAcceleration": "BucketTransferAcceleration"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oss/bucketUserDefinedLogFields",
  "fqn": "pulumi_alicloud.oss",
  "classes": {
   "alicloud:oss/bucketUserDefinedLogFields:BucketUserDefinedLogFields": "BucketUserDefinedLogFields"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "oss/bucketVersioning",
  "fqn": "pulumi_alicloud.oss",
  "classes": {
   "alicloud:oss/bucketVersioning:BucketVersioning": "BucketVersioning"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ots/instance",
  "fqn": "pulumi_alicloud.ots",
  "classes": {
   "alicloud:ots/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ots/instanceAttachment",
  "fqn": "pulumi_alicloud.ots",
  "classes": {
   "alicloud:ots/instanceAttachment:InstanceAttachment": "InstanceAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ots/searchIndex",
  "fqn": "pulumi_alicloud.ots",
  "classes": {
   "alicloud:ots/searchIndex:SearchIndex": "SearchIndex"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ots/secondaryIndex",
  "fqn": "pulumi_alicloud.ots",
  "classes": {
   "alicloud:ots/secondaryIndex:SecondaryIndex": "SecondaryIndex"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ots/table",
  "fqn": "pulumi_alicloud.ots",
  "classes": {
   "alicloud:ots/table:Table": "Table"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ots/tunnel",
  "fqn": "pulumi_alicloud.ots",
  "classes": {
   "alicloud:ots/tunnel:Tunnel": "Tunnel"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "pai/workspaceWorkspace",
  "fqn": "pulumi_alicloud.pai",
  "classes": {
   "alicloud:pai/workspaceWorkspace:WorkspaceWorkspace": "WorkspaceWorkspace"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "polardb/account",
  "fqn": "pulumi_alicloud.polardb",
  "classes": {
   "alicloud:polardb/account:Account": "Account"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "polardb/accountPrivilege",
  "fqn": "pulumi_alicloud.polardb",
  "classes": {
   "alicloud:polardb/accountPrivilege:AccountPrivilege": "AccountPrivilege"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "polardb/backupPolicy",
  "fqn": "pulumi_alicloud.polardb",
  "classes": {
   "alicloud:polardb/backupPolicy:BackupPolicy": "BackupPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "polardb/cluster",
  "fqn": "pulumi_alicloud.polardb",
  "classes": {
   "alicloud:polardb/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "polardb/clusterEndpoint",
  "fqn": "pulumi_alicloud.polardb",
  "classes": {
   "alicloud:polardb/clusterEndpoint:ClusterEndpoint": "ClusterEndpoint"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "polardb/database",
  "fqn": "pulumi_alicloud.polardb",
  "classes": {
   "alicloud:polardb/database:Database": "Database"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "polardb/endpoint",
  "fqn": "pulumi_alicloud.polardb",
  "classes": {
   "alicloud:polardb/endpoint:Endpoint": "Endpoint"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "polardb/endpointAddress",
  "fqn": "pulumi_alicloud.polardb",
  "classes": {
   "alicloud:polardb/endpointAddress:EndpointAddress": "EndpointAddress"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "polardb/globalDatabaseNetwork",
  "fqn": "pulumi_alicloud.polardb",
  "classes": {
   "alicloud:polardb/globalDatabaseNetwork:GlobalDatabaseNetwork": "GlobalDatabaseNetwork"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "polardb/parameterGroup",
  "fqn": "pulumi_alicloud.polardb",
  "classes": {
   "alicloud:polardb/parameterGroup:ParameterGroup": "ParameterGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "polardb/primaryEndpoint",
  "fqn": "pulumi_alicloud.polardb",
  "classes": {
   "alicloud:polardb/primaryEndpoint:PrimaryEndpoint": "PrimaryEndpoint"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "privatelink/vpcEndpoint",
  "fqn": "pulumi_alicloud.privatelink",
  "classes": {
   "alicloud:privatelink/vpcEndpoint:VpcEndpoint": "VpcEndpoint"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "privatelink/vpcEndpointService",
  "fqn": "pulumi_alicloud.privatelink",
  "classes": {
   "alicloud:privatelink/vpcEndpointService:VpcEndpointService": "VpcEndpointService"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "privatelink/vpcEndpointServiceConnection",
  "fqn": "pulumi_alicloud.privatelink",
  "classes": {
   "alicloud:privatelink/vpcEndpointServiceConnection:VpcEndpointServiceConnection": "VpcEndpointServiceConnection"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "privatelink/vpcEndpointServiceResource",
  "fqn": "pulumi_alicloud.privatelink",
  "classes": {
   "alicloud:privatelink/vpcEndpointServiceResource:VpcEndpointServiceResource": "VpcEndpointServiceResource"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "privatelink/vpcEndpointServiceUser",
  "fqn": "pulumi_alicloud.privatelink",
  "classes": {
   "alicloud:privatelink/vpcEndpointServiceUser:VpcEndpointServiceUser": "VpcEndpointServiceUser"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "privatelink/vpcEndpointZone",
  "fqn": "pulumi_alicloud.privatelink",
  "classes": {
   "alicloud:privatelink/vpcEndpointZone:VpcEndpointZone": "VpcEndpointZone"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "pvtz/endpoint",
  "fqn": "pulumi_alicloud.pvtz",
  "classes": {
   "alicloud:pvtz/endpoint:Endpoint": "Endpoint"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "pvtz/rule",
  "fqn": "pulumi_alicloud.pvtz",
  "classes": {
   "alicloud:pvtz/rule:Rule": "Rule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "pvtz/ruleAttachment",
  "fqn": "pulumi_alicloud.pvtz",
  "classes": {
   "alicloud:pvtz/ruleAttachment:RuleAttachment": "RuleAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "pvtz/userVpcAuthorization",
  "fqn": "pulumi_alicloud.pvtz",
  "classes": {
   "alicloud:pvtz/userVpcAuthorization:UserVpcAuthorization": "UserVpcAuthorization"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "pvtz/zone",
  "fqn": "pulumi_alicloud.pvtz",
  "classes": {
   "alicloud:pvtz/zone:Zone": "Zone"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "pvtz/zoneAttachment",
  "fqn": "pulumi_alicloud.pvtz",
  "classes": {
   "alicloud:pvtz/zoneAttachment:ZoneAttachment": "ZoneAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "pvtz/zoneRecord",
  "fqn": "pulumi_alicloud.pvtz",
  "classes": {
   "alicloud:pvtz/zoneRecord:ZoneRecord": "ZoneRecord"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "quickbi/user",
  "fqn": "pulumi_alicloud.quickbi",
  "classes": {
   "alicloud:quickbi/user:User": "User"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "quotas/applicationInfo",
  "fqn": "pulumi_alicloud.quotas",
  "classes": {
   "alicloud:quotas/applicationInfo:ApplicationInfo": "ApplicationInfo"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "quotas/quotaAlarm",
  "fqn": "pulumi_alicloud.quotas",
  "classes": {
   "alicloud:quotas/quotaAlarm:QuotaAlarm": "QuotaAlarm"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "quotas/quotaApplication",
  "fqn": "pulumi_alicloud.quotas",
  "classes": {
   "alicloud:quotas/quotaApplication:QuotaApplication": "QuotaApplication"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "quotas/templateApplications",
  "fqn": "pulumi_alicloud.quotas",
  "classes": {
   "alicloud:quotas/templateApplications:TemplateApplications": "TemplateApplications"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "quotas/templateQuota",
  "fqn": "pulumi_alicloud.quotas",
  "classes": {
   "alicloud:quotas/templateQuota:TemplateQuota": "TemplateQuota"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "quotas/templateService",
  "fqn": "pulumi_alicloud.quotas",
  "classes": {
   "alicloud:quotas/templateService:TemplateService": "TemplateService"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ram/accessKey",
  "fqn": "pulumi_alicloud.ram",
  "classes": {
   "alicloud:ram/accessKey:AccessKey": "AccessKey"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ram/accountAlias",
  "fqn": "pulumi_alicloud.ram",
  "classes": {
   "alicloud:ram/accountAlias:AccountAlias": "AccountAlias"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ram/accountPasswordPolicy",
  "fqn": "pulumi_alicloud.ram",
  "classes": {
   "alicloud:ram/accountPasswordPolicy:AccountPasswordPolicy": "AccountPasswordPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ram/alias",
  "fqn": "pulumi_alicloud.ram",
  "classes": {
   "alicloud:ram/alias:Alias": "Alias"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ram/group",
  "fqn": "pulumi_alicloud.ram",
  "classes": {
   "alicloud:ram/group:Group": "Group"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ram/groupMembership",
  "fqn": "pulumi_alicloud.ram",
  "classes": {
   "alicloud:ram/groupMembership:GroupMembership": "GroupMembership"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ram/groupPolicyAttachment",
  "fqn": "pulumi_alicloud.ram",
  "classes": {
   "alicloud:ram/groupPolicyAttachment:GroupPolicyAttachment": "GroupPolicyAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ram/loginProfile",
  "fqn": "pulumi_alicloud.ram",
  "classes": {
   "alicloud:ram/loginProfile:LoginProfile": "LoginProfile"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ram/policy",
  "fqn": "pulumi_alicloud.ram",
  "classes": {
   "alicloud:ram/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ram/role",
  "fqn": "pulumi_alicloud.ram",
  "classes": {
   "alicloud:ram/role:Role": "Role"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ram/roleAttachment",
  "fqn": "pulumi_alicloud.ram",
  "classes": {
   "alicloud:ram/roleAttachment:RoleAttachment": "RoleAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ram/rolePolicyAttachment",
  "fqn": "pulumi_alicloud.ram",
  "classes": {
   "alicloud:ram/rolePolicyAttachment:RolePolicyAttachment": "RolePolicyAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ram/samlProvider",
  "fqn": "pulumi_alicloud.ram",
  "classes": {
   "alicloud:ram/samlProvider:SamlProvider": "SamlProvider"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ram/securityPreference",
  "fqn": "pulumi_alicloud.ram",
  "classes": {
   "alicloud:ram/securityPreference:SecurityPreference": "SecurityPreference"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ram/user",
  "fqn": "pulumi_alicloud.ram",
  "classes": {
   "alicloud:ram/user:User": "User"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ram/userPolicyAttachment",
  "fqn": "pulumi_alicloud.ram",
  "classes": {
   "alicloud:ram/userPolicyAttachment:UserPolicyAttachment": "UserPolicyAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rdc/organization",
  "fqn": "pulumi_alicloud.rdc",
  "classes": {
   "alicloud:rdc/organization:Organization": "Organization"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rds/account",
  "fqn": "pulumi_alicloud.rds",
  "classes": {
   "alicloud:rds/account:Account": "Account"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rds/accountPrivilege",
  "fqn": "pulumi_alicloud.rds",
  "classes": {
   "alicloud:rds/accountPrivilege:AccountPrivilege": "AccountPrivilege"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rds/backupPolicy",
  "fqn": "pulumi_alicloud.rds",
  "classes": {
   "alicloud:rds/backupPolicy:BackupPolicy": "BackupPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rds/connection",
  "fqn": "pulumi_alicloud.rds",
  "classes": {
   "alicloud:rds/connection:Connection": "Connection"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rds/database",
  "fqn": "pulumi_alicloud.rds",
  "classes": {
   "alicloud:rds/database:Database": "Database"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rds/dbInstanceEndpoint",
  "fqn": "pulumi_alicloud.rds",
  "classes": {
   "alicloud:rds/dbInstanceEndpoint:DbInstanceEndpoint": "DbInstanceEndpoint"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rds/dbInstanceEndpointAddress",
  "fqn": "pulumi_alicloud.rds",
  "classes": {
   "alicloud:rds/dbInstanceEndpointAddress:DbInstanceEndpointAddress": "DbInstanceEndpointAddress"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rds/dbNode",
  "fqn": "pulumi_alicloud.rds",
  "classes": {
   "alicloud:rds/dbNode:DbNode": "DbNode"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rds/ddrInstance",
  "fqn": "pulumi_alicloud.rds",
  "classes": {
   "alicloud:rds/ddrInstance:DdrInstance": "DdrInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rds/instance",
  "fqn": "pulumi_alicloud.rds",
  "classes": {
   "alicloud:rds/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rds/rdsAccount",
  "fqn": "pulumi_alicloud.rds",
  "classes": {
   "alicloud:rds/rdsAccount:RdsAccount": "RdsAccount"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rds/rdsBackup",
  "fqn": "pulumi_alicloud.rds",
  "classes": {
   "alicloud:rds/rdsBackup:RdsBackup": "RdsBackup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rds/rdsCloneDbInstance",
  "fqn": "pulumi_alicloud.rds",
  "classes": {
   "alicloud:rds/rdsCloneDbInstance:RdsCloneDbInstance": "RdsCloneDbInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rds/rdsDbProxy",
  "fqn": "pulumi_alicloud.rds",
  "classes": {
   "alicloud:rds/rdsDbProxy:RdsDbProxy": "RdsDbProxy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rds/rdsInstanceCrossBackupPolicy",
  "fqn": "pulumi_alicloud.rds",
  "classes": {
   "alicloud:rds/rdsInstanceCrossBackupPolicy:RdsInstanceCrossBackupPolicy": "RdsInstanceCrossBackupPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rds/rdsParameterGroup",
  "fqn": "pulumi_alicloud.rds",
  "classes": {
   "alicloud:rds/rdsParameterGroup:RdsParameterGroup": "RdsParameterGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rds/rdsServiceLinkedRole",
  "fqn": "pulumi_alicloud.rds",
  "classes": {
   "alicloud:rds/rdsServiceLinkedRole:RdsServiceLinkedRole": "RdsServiceLinkedRole"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rds/rdsUpgradeDbInstance",
  "fqn": "pulumi_alicloud.rds",
  "classes": {
   "alicloud:rds/rdsUpgradeDbInstance:RdsUpgradeDbInstance": "RdsUpgradeDbInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rds/readOnlyInstance",
  "fqn": "pulumi_alicloud.rds",
  "classes": {
   "alicloud:rds/readOnlyInstance:ReadOnlyInstance": "ReadOnlyInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rds/readWriteSplittingConnection",
  "fqn": "pulumi_alicloud.rds",
  "classes": {
   "alicloud:rds/readWriteSplittingConnection:ReadWriteSplittingConnection": "ReadWriteSplittingConnection"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "realtimecompute/vvpInstance",
  "fqn": "pulumi_alicloud.realtimecompute",
  "classes": {
   "alicloud:realtimecompute/vvpInstance:VvpInstance": "VvpInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "redis/tairInstance",
  "fqn": "pulumi_alicloud.redis",
  "classes": {
   "alicloud:redis/tairInstance:TairInstance": "TairInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "resourcemanager/account",
  "fqn": "pulumi_alicloud.resourcemanager",
  "classes": {
   "alicloud:resourcemanager/account:Account": "Account"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "resourcemanager/controlPolicy",
  "fqn": "pulumi_alicloud.resourcemanager",
  "classes": {
   "alicloud:resourcemanager/controlPolicy:ControlPolicy": "ControlPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "resourcemanager/controlPolicyAttachment",
  "fqn": "pulumi_alicloud.resourcemanager",
  "classes": {
   "alicloud:resourcemanager/controlPolicyAttachment:ControlPolicyAttachment": "ControlPolicyAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "resourcemanager/delegatedAdministrator",
  "fqn": "pulumi_alicloud.resourcemanager",
  "classes": {
   "alicloud:resourcemanager/delegatedAdministrator:DelegatedAdministrator": "DelegatedAdministrator"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "resourcemanager/folder",
  "fqn": "pulumi_alicloud.resourcemanager",
  "classes": {
   "alicloud:resourcemanager/folder:Folder": "Folder"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "resourcemanager/handshake",
  "fqn": "pulumi_alicloud.resourcemanager",
  "classes": {
   "alicloud:resourcemanager/handshake:Handshake": "Handshake"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "resourcemanager/policy",
  "fqn": "pulumi_alicloud.resourcemanager",
  "classes": {
   "alicloud:resourcemanager/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "resourcemanager/policyAttachment",
  "fqn": "pulumi_alicloud.resourcemanager",
  "classes": {
   "alicloud:resourcemanager/policyAttachment:PolicyAttachment": "PolicyAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "resourcemanager/policyVersion",
  "fqn": "pulumi_alicloud.resourcemanager",
  "classes": {
   "alicloud:resourcemanager/policyVersion:PolicyVersion": "PolicyVersion"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "resourcemanager/resourceDirectory",
  "fqn": "pulumi_alicloud.resourcemanager",
  "classes": {
   "alicloud:resourcemanager/resourceDirectory:ResourceDirectory": "ResourceDirectory"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "resourcemanager/resourceGroup",
  "fqn": "pulumi_alicloud.resourcemanager",
  "classes": {
   "alicloud:resourcemanager/resourceGroup:ResourceGroup": "ResourceGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "resourcemanager/resourceShare",
  "fqn": "pulumi_alicloud.resourcemanager",
  "classes": {
   "alicloud:resourcemanager/resourceShare:ResourceShare": "ResourceShare"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "resourcemanager/role",
  "fqn": "pulumi_alicloud.resourcemanager",
  "classes": {
   "alicloud:resourcemanager/role:Role": "Role"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "resourcemanager/savedQuery",
  "fqn": "pulumi_alicloud.resourcemanager",
  "classes": {
   "alicloud:resourcemanager/savedQuery:SavedQuery": "SavedQuery"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "resourcemanager/serviceLinkedRole",
  "fqn": "pulumi_alicloud.resourcemanager",
  "classes": {
   "alicloud:resourcemanager/serviceLinkedRole:ServiceLinkedRole": "ServiceLinkedRole"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "resourcemanager/sharedResource",
  "fqn": "pulumi_alicloud.resourcemanager",
  "classes": {
   "alicloud:resourcemanager/sharedResource:SharedResource": "SharedResource"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "resourcemanager/sharedTarget",
  "fqn": "pulumi_alicloud.resourcemanager",
  "classes": {
   "alicloud:resourcemanager/sharedTarget:SharedTarget": "SharedTarget"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rocketmq/acl",
  "fqn": "pulumi_alicloud.rocketmq",
  "classes": {
   "alicloud:rocketmq/acl:Acl": "Acl"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rocketmq/aclRule",
  "fqn": "pulumi_alicloud.rocketmq",
  "classes": {
   "alicloud:rocketmq/aclRule:AclRule": "AclRule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rocketmq/clientUser",
  "fqn": "pulumi_alicloud.rocketmq",
  "classes": {
   "alicloud:rocketmq/clientUser:ClientUser": "ClientUser"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rocketmq/consumerGroup",
  "fqn": "pulumi_alicloud.rocketmq",
  "classes": {
   "alicloud:rocketmq/consumerGroup:ConsumerGroup": "ConsumerGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rocketmq/dnatEntry",
  "fqn": "pulumi_alicloud.rocketmq",
  "classes": {
   "alicloud:rocketmq/dnatEntry:DnatEntry": "DnatEntry"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rocketmq/group",
  "fqn": "pulumi_alicloud.rocketmq",
  "classes": {
   "alicloud:rocketmq/group:Group": "Group"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rocketmq/instance",
  "fqn": "pulumi_alicloud.rocketmq",
  "classes": {
   "alicloud:rocketmq/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rocketmq/qos",
  "fqn": "pulumi_alicloud.rocketmq",
  "classes": {
   "alicloud:rocketmq/qos:Qos": "Qos"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rocketmq/qosCar",
  "fqn": "pulumi_alicloud.rocketmq",
  "classes": {
   "alicloud:rocketmq/qosCar:QosCar": "QosCar"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rocketmq/qosPolicy",
  "fqn": "pulumi_alicloud.rocketmq",
  "classes": {
   "alicloud:rocketmq/qosPolicy:QosPolicy": "QosPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rocketmq/rocketMQInstance",
  "fqn": "pulumi_alicloud.rocketmq",
  "classes": {
   "alicloud:rocketmq/rocketMQInstance:RocketMQInstance": "RocketMQInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rocketmq/rocketMQTopic",
  "fqn": "pulumi_alicloud.rocketmq",
  "classes": {
   "alicloud:rocketmq/rocketMQTopic:RocketMQTopic": "RocketMQTopic"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rocketmq/snatEntry",
  "fqn": "pulumi_alicloud.rocketmq",
  "classes": {
   "alicloud:rocketmq/snatEntry:SnatEntry": "SnatEntry"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "rocketmq/topic",
  "fqn": "pulumi_alicloud.rocketmq",
  "classes": {
   "alicloud:rocketmq/topic:Topic": "Topic"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ros/changeSet",
  "fqn": "pulumi_alicloud.ros",
  "classes": {
   "alicloud:ros/changeSet:ChangeSet": "ChangeSet"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ros/stack",
  "fqn": "pulumi_alicloud.ros",
  "classes": {
   "alicloud:ros/stack:Stack": "Stack"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ros/stackGroup",
  "fqn": "pulumi_alicloud.ros",
  "classes": {
   "alicloud:ros/stackGroup:StackGroup": "StackGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ros/stackInstance",
  "fqn": "pulumi_alicloud.ros",
  "classes": {
   "alicloud:ros/stackInstance:StackInstance": "StackInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ros/template",
  "fqn": "pulumi_alicloud.ros",
  "classes": {
   "alicloud:ros/template:Template": "Template"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "ros/templateScratch",
  "fqn": "pulumi_alicloud.ros",
  "classes": {
   "alicloud:ros/templateScratch:TemplateScratch": "TemplateScratch"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "sae/application",
  "fqn": "pulumi_alicloud.sae",
  "classes": {
   "alicloud:sae/application:Application": "Application"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "sae/applicationScalingRule",
  "fqn": "pulumi_alicloud.sae",
  "classes": {
   "alicloud:sae/applicationScalingRule:ApplicationScalingRule": "ApplicationScalingRule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "sae/configMap",
  "fqn": "pulumi_alicloud.sae",
  "classes": {
   "alicloud:sae/configMap:ConfigMap": "ConfigMap"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "sae/greyTagRoute",
  "fqn": "pulumi_alicloud.sae",
  "classes": {
   "alicloud:sae/greyTagRoute:GreyTagRoute": "GreyTagRoute"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "sae/ingress",
  "fqn": "pulumi_alicloud.sae",
  "classes": {
   "alicloud:sae/ingress:Ingress": "Ingress"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "sae/loadBalancerInternet",
  "fqn": "pulumi_alicloud.sae",
  "classes": {
   "alicloud:sae/loadBalancerInternet:LoadBalancerInternet": "LoadBalancerInternet"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "sae/loadBalancerIntranet",
  "fqn": "pulumi_alicloud.sae",
  "classes": {
   "alicloud:sae/loadBalancerIntranet:LoadBalancerIntranet": "LoadBalancerIntranet"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "sae/namespace",
  "fqn": "pulumi_alicloud.sae",
  "classes": {
   "alicloud:sae/namespace:Namespace": "Namespace"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "sag/smartagFlowLog",
  "fqn": "pulumi_alicloud.sag",
  "classes": {
   "alicloud:sag/smartagFlowLog:SmartagFlowLog": "SmartagFlowLog"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "scdn/domain",
  "fqn": "pulumi_alicloud.scdn",
  "classes": {
   "alicloud:scdn/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "scdn/domainConfig",
  "fqn": "pulumi_alicloud.scdn",
  "classes": {
   "alicloud:scdn/domainConfig:DomainConfig": "DomainConfig"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "schedulerx/namespace",
  "fqn": "pulumi_alicloud.schedulerx",
  "classes": {
   "alicloud:schedulerx/namespace:Namespace": "Namespace"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "sddp/config",
  "fqn": "pulumi_alicloud.sddp",
  "classes": {
   "alicloud:sddp/config:Config": "Config"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "sddp/dataLimit",
  "fqn": "pulumi_alicloud.sddp",
  "classes": {
   "alicloud:sddp/dataLimit:DataLimit": "DataLimit"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "sddp/instance",
  "fqn": "pulumi_alicloud.sddp",
  "classes": {
   "alicloud:sddp/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "sddp/rule",
  "fqn": "pulumi_alicloud.sddp",
  "classes": {
   "alicloud:sddp/rule:Rule": "Rule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "securitycenter/group",
  "fqn": "pulumi_alicloud.securitycenter",
  "classes": {
   "alicloud:securitycenter/group:Group": "Group"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "securitycenter/serviceLinkedRole",
  "fqn": "pulumi_alicloud.securitycenter",
  "classes": {
   "alicloud:securitycenter/serviceLinkedRole:ServiceLinkedRole": "ServiceLinkedRole"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "selectdb/dbCluster",
  "fqn": "pulumi_alicloud.selectdb",
  "classes": {
   "alicloud:selectdb/dbCluster:DbCluster": "DbCluster"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "selectdb/dbInstance",
  "fqn": "pulumi_alicloud.selectdb",
  "classes": {
   "alicloud:selectdb/dbInstance:DbInstance": "DbInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "servicecatalog/portfolio",
  "fqn": "pulumi_alicloud.servicecatalog",
  "classes": {
   "alicloud:servicecatalog/portfolio:Portfolio": "Portfolio"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "servicecatalog/principalPortfolioAssociation",
  "fqn": "pulumi_alicloud.servicecatalog",
  "classes": {
   "alicloud:servicecatalog/principalPortfolioAssociation:PrincipalPortfolioAssociation": "PrincipalPortfolioAssociation"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "servicecatalog/product",
  "fqn": "pulumi_alicloud.servicecatalog",
  "classes": {
   "alicloud:servicecatalog/product:Product": "Product"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "servicecatalog/productPortfolioAssociation",
  "fqn": "pulumi_alicloud.servicecatalog",
  "classes": {
   "alicloud:servicecatalog/productPortfolioAssociation:ProductPortfolioAssociation": "ProductPortfolioAssociation"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "servicecatalog/productVersion",
  "fqn": "pulumi_alicloud.servicecatalog",
  "classes": {
   "alicloud:servicecatalog/productVersion:ProductVersion": "ProductVersion"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "servicecatalog/provisionedProduct",
  "fqn": "pulumi_alicloud.servicecatalog",
  "classes": {
   "alicloud:servicecatalog/provisionedProduct:ProvisionedProduct": "ProvisionedProduct"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "servicemesh/extensionProvider",
  "fqn": "pulumi_alicloud.servicemesh",
  "classes": {
   "alicloud:servicemesh/extensionProvider:ExtensionProvider": "ExtensionProvider"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "servicemesh/serviceMesh",
  "fqn": "pulumi_alicloud.servicemesh",
  "classes": {
   "alicloud:servicemesh/serviceMesh:ServiceMesh": "ServiceMesh"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "servicemesh/userPermission",
  "fqn": "pulumi_alicloud.servicemesh",
  "classes": {
   "alicloud:servicemesh/userPermission:UserPermission": "UserPermission"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "simpleapplicationserver/customImage",
  "fqn": "pulumi_alicloud.simpleapplicationserver",
  "classes": {
   "alicloud:simpleapplicationserver/customImage:CustomImage": "CustomImage"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "simpleapplicationserver/firewallRule",
  "fqn": "pulumi_alicloud.simpleapplicationserver",
  "classes": {
   "alicloud:simpleapplicationserver/firewallRule:FirewallRule": "FirewallRule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "simpleapplicationserver/instance",
  "fqn": "pulumi_alicloud.simpleapplicationserver",
  "classes": {
   "alicloud:simpleapplicationserver/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "simpleapplicationserver/snapshot",
  "fqn": "pulumi_alicloud.simpleapplicationserver",
  "classes": {
   "alicloud:simpleapplicationserver/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "slb/acl",
  "fqn": "pulumi_alicloud.slb",
  "classes": {
   "alicloud:slb/acl:Acl": "Acl"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "slb/aclEntryAttachment",
  "fqn": "pulumi_alicloud.slb",
  "classes": {
   "alicloud:slb/aclEntryAttachment:AclEntryAttachment": "AclEntryAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "slb/applicationLoadBalancer",
  "fqn": "pulumi_alicloud.slb",
  "classes": {
   "alicloud:slb/applicationLoadBalancer:ApplicationLoadBalancer": "ApplicationLoadBalancer"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "slb/attachment",
  "fqn": "pulumi_alicloud.slb",
  "classes": {
   "alicloud:slb/attachment:Attachment": "Attachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "slb/backendServer",
  "fqn": "pulumi_alicloud.slb",
  "classes": {
   "alicloud:slb/backendServer:BackendServer": "BackendServer"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "slb/caCertificate",
  "fqn": "pulumi_alicloud.slb",
  "classes": {
   "alicloud:slb/caCertificate:CaCertificate": "CaCertificate"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "slb/domainExtension",
  "fqn": "pulumi_alicloud.slb",
  "classes": {
   "alicloud:slb/domainExtension:DomainExtension": "DomainExtension"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "slb/listener",
  "fqn": "pulumi_alicloud.slb",
  "classes": {
   "alicloud:slb/listener:Listener": "Listener"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "slb/loadBalancer",
  "fqn": "pulumi_alicloud.slb",
  "classes": {
   "alicloud:slb/loadBalancer:LoadBalancer": "LoadBalancer"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "slb/masterSlaveServerGroup",
  "fqn": "pulumi_alicloud.slb",
  "classes": {
   "alicloud:slb/masterSlaveServerGroup:MasterSlaveServerGroup": "MasterSlaveServerGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "slb/rule",
  "fqn": "pulumi_alicloud.slb",
  "classes": {
   "alicloud:slb/rule:Rule": "Rule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "slb/serverCertificate",
  "fqn": "pulumi_alicloud.slb",
  "classes": {
   "alicloud:slb/serverCertificate:ServerCertificate": "ServerCertificate"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "slb/serverGroup",
  "fqn": "pulumi_alicloud.slb",
  "classes": {
   "alicloud:slb/serverGroup:ServerGroup": "ServerGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "slb/serverGroupServerAttachment",
  "fqn": "pulumi_alicloud.slb",
  "classes": {
   "alicloud:slb/serverGroupServerAttachment:ServerGroupServerAttachment": "ServerGroupServerAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "slb/tlsCipherPolicy",
  "fqn": "pulumi_alicloud.slb",
  "classes": {
   "alicloud:slb/tlsCipherPolicy:TlsCipherPolicy": "TlsCipherPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "sls/alert",
  "fqn": "pulumi_alicloud.sls",
  "classes": {
   "alicloud:sls/alert:Alert": "Alert"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "sls/collectionPolicy",
  "fqn": "pulumi_alicloud.sls",
  "classes": {
   "alicloud:sls/collectionPolicy:CollectionPolicy": "CollectionPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "sls/scheduledSql",
  "fqn": "pulumi_alicloud.sls",
  "classes": {
   "alicloud:sls/scheduledSql:ScheduledSql": "ScheduledSql"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "sms/shortUrl",
  "fqn": "pulumi_alicloud.sms",
  "classes": {
   "alicloud:sms/shortUrl:ShortUrl": "ShortUrl"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "tag/metaTag",
  "fqn": "pulumi_alicloud.tag",
  "classes": {
   "alicloud:tag/metaTag:MetaTag": "MetaTag"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "tag/policy",
  "fqn": "pulumi_alicloud.tag",
  "classes": {
   "alicloud:tag/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "tag/policyAttachment",
  "fqn": "pulumi_alicloud.tag",
  "classes": {
   "alicloud:tag/policyAttachment:PolicyAttachment": "PolicyAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "threatdetection/antiBruteForceRule",
  "fqn": "pulumi_alicloud.threatdetection",
  "classes": {
   "alicloud:threatdetection/antiBruteForceRule:AntiBruteForceRule": "AntiBruteForceRule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "threatdetection/backupPolicy",
  "fqn": "pulumi_alicloud.threatdetection",
  "classes": {
   "alicloud:threatdetection/backupPolicy:BackupPolicy": "BackupPolicy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "threatdetection/baselineStrategy",
  "fqn": "pulumi_alicloud.threatdetection",
  "classes": {
   "alicloud:threatdetection/baselineStrategy:BaselineStrategy": "BaselineStrategy"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "threatdetection/clientFileProtect",
  "fqn": "pulumi_alicloud.threatdetection",
  "classes": {
   "alicloud:threatdetection/clientFileProtect:ClientFileProtect": "ClientFileProtect"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "threatdetection/clientUserDefineRule",
  "fqn": "pulumi_alicloud.threatdetection",
  "classes": {
   "alicloud:threatdetection/clientUserDefineRule:ClientUserDefineRule": "ClientUserDefineRule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "threatdetection/fileUploadLimit",
  "fqn": "pulumi_alicloud.threatdetection",
  "classes": {
   "alicloud:threatdetection/fileUploadLimit:FileUploadLimit": "FileUploadLimit"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "threatdetection/honeyPot",
  "fqn": "pulumi_alicloud.threatdetection",
  "classes": {
   "alicloud:threatdetection/honeyPot:HoneyPot": "HoneyPot"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "threatdetection/honeypotNode",
  "fqn": "pulumi_alicloud.threatdetection",
  "classes": {
   "alicloud:threatdetection/honeypotNode:HoneypotNode": "HoneypotNode"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "threatdetection/honeypotPreset",
  "fqn": "pulumi_alicloud.threatdetection",
  "classes": {
   "alicloud:threatdetection/honeypotPreset:HoneypotPreset": "HoneypotPreset"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "threatdetection/honeypotProbe",
  "fqn": "pulumi_alicloud.threatdetection",
  "classes": {
   "alicloud:threatdetection/honeypotProbe:HoneypotProbe": "HoneypotProbe"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "threatdetection/imageEventOperation",
  "fqn": "pulumi_alicloud.threatdetection",
  "classes": {
   "alicloud:threatdetection/imageEventOperation:ImageEventOperation": "ImageEventOperation"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "threatdetection/instance",
  "fqn": "pulumi_alicloud.threatdetection",
  "classes": {
   "alicloud:threatdetection/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "threatdetection/maliciousFileWhitelistConfig",
  "fqn": "pulumi_alicloud.threatdetection",
  "classes": {
   "alicloud:threatdetection/maliciousFileWhitelistConfig:MaliciousFileWhitelistConfig": "MaliciousFileWhitelistConfig"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "threatdetection/ossScanConfig",
  "fqn": "pulumi_alicloud.threatdetection",
  "classes": {
   "alicloud:threatdetection/ossScanConfig:OssScanConfig": "OssScanConfig"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "threatdetection/sasTrail",
  "fqn": "pulumi_alicloud.threatdetection",
  "classes": {
   "alicloud:threatdetection/sasTrail:SasTrail": "SasTrail"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "threatdetection/vulWhitelist",
  "fqn": "pulumi_alicloud.threatdetection",
  "classes": {
   "alicloud:threatdetection/vulWhitelist:VulWhitelist": "VulWhitelist"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "threatdetection/webLockConfig",
  "fqn": "pulumi_alicloud.threatdetection",
  "classes": {
   "alicloud:threatdetection/webLockConfig:WebLockConfig": "WebLockConfig"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "tsdb/instance",
  "fqn": "pulumi_alicloud.tsdb",
  "classes": {
   "alicloud:tsdb/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "videosurveillance/systemGroup",
  "fqn": "pulumi_alicloud.videosurveillance",
  "classes": {
   "alicloud:videosurveillance/systemGroup:SystemGroup": "SystemGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vod/domain",
  "fqn": "pulumi_alicloud.vod",
  "classes": {
   "alicloud:vod/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vod/editingProject",
  "fqn": "pulumi_alicloud.vod",
  "classes": {
   "alicloud:vod/editingProject:EditingProject": "EditingProject"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/bgpGroup",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/bgpGroup:BgpGroup": "BgpGroup"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/bgpNetwork",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/bgpNetwork:BgpNetwork": "BgpNetwork"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/bgpPeer",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/bgpPeer:BgpPeer": "BgpPeer"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/commonBandwithPackage",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/commonBandwithPackage:CommonBandwithPackage": "CommonBandwithPackage"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/commonBandwithPackageAttachment",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/commonBandwithPackageAttachment:CommonBandwithPackageAttachment": "CommonBandwithPackageAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/dhcpOptionsSet",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/dhcpOptionsSet:DhcpOptionsSet": "DhcpOptionsSet"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/dhcpOptionsSetAttachment",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/dhcpOptionsSetAttachment:DhcpOptionsSetAttachment": "DhcpOptionsSetAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/flowLog",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/flowLog:FlowLog": "FlowLog"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/forwardEntry",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/forwardEntry:ForwardEntry": "ForwardEntry"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/gatewayEndpoint",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/gatewayEndpoint:GatewayEndpoint": "GatewayEndpoint"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/gatewayEndpointRouteTableAttachment",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/gatewayEndpointRouteTableAttachment:GatewayEndpointRouteTableAttachment": "GatewayEndpointRouteTableAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/gatewayRouteTableAttachment",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/gatewayRouteTableAttachment:GatewayRouteTableAttachment": "GatewayRouteTableAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/hAVip",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/hAVip:HAVip": "HAVip"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/hAVipAttachment",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/hAVipAttachment:HAVipAttachment": "HAVipAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/haVipv2",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/haVipv2:HaVipv2": "HaVipv2"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/ipamIpam",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/ipamIpam:IpamIpam": "IpamIpam"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/ipamIpamPool",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/ipamIpamPool:IpamIpamPool": "IpamIpamPool"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/ipamIpamPoolCidr",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/ipamIpamPoolCidr:IpamIpamPoolCidr": "IpamIpamPoolCidr"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/ipamIpamScope",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/ipamIpamScope:IpamIpamScope": "IpamIpamScope"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/ipv4CidrBlock",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/ipv4CidrBlock:Ipv4CidrBlock": "Ipv4CidrBlock"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/ipv4Gateway",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/ipv4Gateway:Ipv4Gateway": "Ipv4Gateway"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/ipv6Address",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/ipv6Address:Ipv6Address": "Ipv6Address"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/ipv6EgressRule",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/ipv6EgressRule:Ipv6EgressRule": "Ipv6EgressRule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/ipv6Gateway",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/ipv6Gateway:Ipv6Gateway": "Ipv6Gateway"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/ipv6InternetBandwidth",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/ipv6InternetBandwidth:Ipv6InternetBandwidth": "Ipv6InternetBandwidth"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/natGateway",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/natGateway:NatGateway": "NatGateway"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/natIp",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/natIp:NatIp": "NatIp"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/natIpCidr",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/natIpCidr:NatIpCidr": "NatIpCidr"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/network",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/network:Network": "Network"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/networkAcl",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/networkAcl:NetworkAcl": "NetworkAcl"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/networkAclAttachment",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/networkAclAttachment:NetworkAclAttachment": "NetworkAclAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/networkAclEntries",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/networkAclEntries:NetworkAclEntries": "NetworkAclEntries"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/networkInterface",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/networkInterface:NetworkInterface": "NetworkInterface"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/networkInterfaceAttachment",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/networkInterfaceAttachment:NetworkInterfaceAttachment": "NetworkInterfaceAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/peerConnection",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/peerConnection:PeerConnection": "PeerConnection"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/peerConnectionAccepter",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/peerConnectionAccepter:PeerConnectionAccepter": "PeerConnectionAccepter"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/prefixList",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/prefixList:PrefixList": "PrefixList"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/publicIpAddressPool",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/publicIpAddressPool:PublicIpAddressPool": "PublicIpAddressPool"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/publicIpAddressPoolCidrBlock",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/publicIpAddressPoolCidrBlock:PublicIpAddressPoolCidrBlock": "PublicIpAddressPoolCidrBlock"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/routeEntry",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/routeEntry:RouteEntry": "RouteEntry"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/routeTable",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/routeTable:RouteTable": "RouteTable"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/routeTableAttachment",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/routeTableAttachment:RouteTableAttachment": "RouteTableAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/routerInterface",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/routerInterface:RouterInterface": "RouterInterface"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/routerInterfaceConnection",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/routerInterfaceConnection:RouterInterfaceConnection": "RouterInterfaceConnection"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/snatEntry",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/snatEntry:SnatEntry": "SnatEntry"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/subnet",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/subnet:Subnet": "Subnet"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/switch",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/switch:Switch": "Switch"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/trafficMirrorFilter",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/trafficMirrorFilter:TrafficMirrorFilter": "TrafficMirrorFilter"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/trafficMirrorFilterEgressRule",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/trafficMirrorFilterEgressRule:TrafficMirrorFilterEgressRule": "TrafficMirrorFilterEgressRule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/trafficMirrorFilterIngressRule",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/trafficMirrorFilterIngressRule:TrafficMirrorFilterIngressRule": "TrafficMirrorFilterIngressRule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/trafficMirrorSession",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/trafficMirrorSession:TrafficMirrorSession": "TrafficMirrorSession"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/vbrHa",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/vbrHa:VbrHa": "VbrHa"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/vpcNetworkAclAttachment",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/vpcNetworkAclAttachment:VpcNetworkAclAttachment": "VpcNetworkAclAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpc/vswitchCidrReservation",
  "fqn": "pulumi_alicloud.vpc",
  "classes": {
   "alicloud:vpc/vswitchCidrReservation:VswitchCidrReservation": "VswitchCidrReservation"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpn/connection",
  "fqn": "pulumi_alicloud.vpn",
  "classes": {
   "alicloud:vpn/connection:Connection": "Connection"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpn/customerGateway",
  "fqn": "pulumi_alicloud.vpn",
  "classes": {
   "alicloud:vpn/customerGateway:CustomerGateway": "CustomerGateway"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpn/gateway",
  "fqn": "pulumi_alicloud.vpn",
  "classes": {
   "alicloud:vpn/gateway:Gateway": "Gateway"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpn/gatewayVcoRoute",
  "fqn": "pulumi_alicloud.vpn",
  "classes": {
   "alicloud:vpn/gatewayVcoRoute:GatewayVcoRoute": "GatewayVcoRoute"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpn/gatewayVpnAttachment",
  "fqn": "pulumi_alicloud.vpn",
  "classes": {
   "alicloud:vpn/gatewayVpnAttachment:GatewayVpnAttachment": "GatewayVpnAttachment"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpn/ipsecServer",
  "fqn": "pulumi_alicloud.vpn",
  "classes": {
   "alicloud:vpn/ipsecServer:IpsecServer": "IpsecServer"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpn/pbrRouteEntry",
  "fqn": "pulumi_alicloud.vpn",
  "classes": {
   "alicloud:vpn/pbrRouteEntry:PbrRouteEntry": "PbrRouteEntry"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpn/routeEntry",
  "fqn": "pulumi_alicloud.vpn",
  "classes": {
   "alicloud:vpn/routeEntry:RouteEntry": "RouteEntry"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpn/sslVpnClientCert",
  "fqn": "pulumi_alicloud.vpn",
  "classes": {
   "alicloud:vpn/sslVpnClientCert:SslVpnClientCert": "SslVpnClientCert"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "vpn/sslVpnServer",
  "fqn": "pulumi_alicloud.vpn",
  "classes": {
   "alicloud:vpn/sslVpnServer:SslVpnServer": "SslVpnServer"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "waf/certificate",
  "fqn": "pulumi_alicloud.waf",
  "classes": {
   "alicloud:waf/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "waf/domain",
  "fqn": "pulumi_alicloud.waf",
  "classes": {
   "alicloud:waf/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "waf/instance",
  "fqn": "pulumi_alicloud.waf",
  "classes": {
   "alicloud:waf/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "waf/protectionModule",
  "fqn": "pulumi_alicloud.waf",
  "classes": {
   "alicloud:waf/protectionModule:ProtectionModule": "ProtectionModule"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "wafv3/defenseTemplate",
  "fqn": "pulumi_alicloud.wafv3",
  "classes": {
   "alicloud:wafv3/defenseTemplate:DefenseTemplate": "DefenseTemplate"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "wafv3/domain",
  "fqn": "pulumi_alicloud.wafv3",
  "classes": {
   "alicloud:wafv3/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "wafv3/instance",
  "fqn": "pulumi_alicloud.wafv3",
  "classes": {
   "alicloud:wafv3/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "yundun/bastionHostInstance",
  "fqn": "pulumi_alicloud.yundun",
  "classes": {
   "alicloud:yundun/bastionHostInstance:BastionHostInstance": "BastionHostInstance"
  }
 },
 {
  "pkg": "alicloud",
  "mod": "yundun/dBAuditInstance",
  "fqn": "pulumi_alicloud.yundun",
  "classes": {
   "alicloud:yundun/dBAuditInstance:DBAuditInstance": "DBAuditInstance"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "alicloud",
  "token": "pulumi:providers:alicloud",
  "fqn": "pulumi_alicloud",
  "class": "Provider"
 }
]
"""
)
